@@ -19,6 +19,48 @@ package org.apache.maven.repository.internal;
  * under the License.
  */
 
+import org.apache.commons.lang3.Validate;
+import org.apache.maven.artifact.repository.metadata.Snapshot;
+import org.apache.maven.artifact.repository.metadata.SnapshotVersion;
+import org.apache.maven.artifact.repository.metadata.Versioning;
+import org.apache.maven.artifact.repository.metadata.io.xpp3.MetadataXpp3Reader;
+import org.codehaus.plexus.component.annotations.Component;
+import org.codehaus.plexus.component.annotations.Requirement;
+import org.codehaus.plexus.util.IOUtil;
+import org.codehaus.plexus.util.StringUtils;
+import org.eclipse.aether.RepositoryCache;
+import org.eclipse.aether.RepositoryEvent;
+import org.eclipse.aether.RepositoryEvent.EventType;
+import org.eclipse.aether.RepositorySystemSession;
+import org.eclipse.aether.RequestTrace;
+import org.eclipse.aether.SyncContext;
+import org.eclipse.aether.artifact.Artifact;
+import org.eclipse.aether.impl.MetadataResolver;
+import org.eclipse.aether.impl.RepositoryEventDispatcher;
+import org.eclipse.aether.impl.SyncContextFactory;
+import org.eclipse.aether.impl.VersionResolver;
+import org.eclipse.aether.internal.impl.CacheUtils;
+import org.eclipse.aether.metadata.DefaultMetadata;
+import org.eclipse.aether.metadata.Metadata;
+import org.eclipse.aether.repository.ArtifactRepository;
+import org.eclipse.aether.repository.LocalRepository;
+import org.eclipse.aether.repository.RemoteRepository;
+import org.eclipse.aether.repository.WorkspaceReader;
+import org.eclipse.aether.repository.WorkspaceRepository;
+import org.eclipse.aether.resolution.MetadataRequest;
+import org.eclipse.aether.resolution.MetadataResult;
+import org.eclipse.aether.resolution.VersionRequest;
+import org.eclipse.aether.resolution.VersionResolutionException;
+import org.eclipse.aether.resolution.VersionResult;
+import org.eclipse.aether.spi.locator.Service;
+import org.eclipse.aether.spi.locator.ServiceLocator;
+import org.eclipse.aether.spi.log.Logger;
+import org.eclipse.aether.spi.log.LoggerFactory;
+import org.eclipse.aether.spi.log.NullLoggerFactory;
+import org.eclipse.aether.util.ConfigUtils;
+
+import javax.inject.Inject;
+import javax.inject.Named;
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.IOException;
@@ -28,48 +70,10 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
-import org.apache.maven.artifact.repository.metadata.Snapshot;
-import org.apache.maven.artifact.repository.metadata.SnapshotVersion;
-import org.apache.maven.artifact.repository.metadata.Versioning;
-import org.apache.maven.artifact.repository.metadata.io.xpp3.MetadataXpp3Reader;
-import org.codehaus.plexus.component.annotations.Component;
-import org.codehaus.plexus.component.annotations.Requirement;
-import org.codehaus.plexus.util.IOUtil;
-import org.codehaus.plexus.util.StringUtils;
-import org.sonatype.aether.ConfigurationProperties;
-import org.sonatype.aether.RepositoryCache;
-import org.sonatype.aether.RequestTrace;
-import org.sonatype.aether.RepositoryEvent.EventType;
-import org.sonatype.aether.RepositorySystemSession;
-import org.sonatype.aether.SyncContext;
-import org.sonatype.aether.util.DefaultRequestTrace;
-import org.sonatype.aether.util.listener.DefaultRepositoryEvent;
-import org.sonatype.aether.util.metadata.DefaultMetadata;
-import org.sonatype.aether.artifact.Artifact;
-import org.sonatype.aether.impl.MetadataResolver;
-import org.sonatype.aether.impl.RepositoryEventDispatcher;
-import org.sonatype.aether.impl.SyncContextFactory;
-import org.sonatype.aether.impl.VersionResolver;
-import org.sonatype.aether.impl.internal.CacheUtils;
-import org.sonatype.aether.metadata.Metadata;
-import org.sonatype.aether.repository.ArtifactRepository;
-import org.sonatype.aether.repository.LocalRepository;
-import org.sonatype.aether.repository.RemoteRepository;
-import org.sonatype.aether.repository.WorkspaceReader;
-import org.sonatype.aether.repository.WorkspaceRepository;
-import org.sonatype.aether.resolution.MetadataRequest;
-import org.sonatype.aether.resolution.MetadataResult;
-import org.sonatype.aether.resolution.VersionRequest;
-import org.sonatype.aether.resolution.VersionResolutionException;
-import org.sonatype.aether.resolution.VersionResult;
-import org.sonatype.aether.spi.locator.Service;
-import org.sonatype.aether.spi.locator.ServiceLocator;
-import org.sonatype.aether.spi.log.Logger;
-import org.sonatype.aether.spi.log.NullLogger;
-
 /**
  * @author Benjamin Bentmann
  */
+@Named
 @Component( role = VersionResolver.class )
 public class DefaultVersionResolver
     implements VersionResolver, Service
@@ -84,8 +88,8 @@ public class DefaultVersionResolver
     private static final String SNAPSHOT = "SNAPSHOT";
 
     @SuppressWarnings( "unused" )
-    @Requirement
-    private Logger logger = NullLogger.INSTANCE;
+    @Requirement( role = LoggerFactory.class )
+    private Logger logger = NullLoggerFactory.LOGGER;
 
     @Requirement
     private MetadataResolver metadataResolver;
@@ -96,54 +100,64 @@ public class DefaultVersionResolver
     @Requirement
     private RepositoryEventDispatcher repositoryEventDispatcher;
 
+    public DefaultVersionResolver()
+    {
+        // enable no-arg constructor
+    }
+
+    @Inject
+    DefaultVersionResolver( MetadataResolver metadataResolver, SyncContextFactory syncContextFactory,
+                            RepositoryEventDispatcher repositoryEventDispatcher, LoggerFactory loggerFactory )
+    {
+        setMetadataResolver( metadataResolver );
+        setSyncContextFactory( syncContextFactory );
+        setLoggerFactory( loggerFactory );
+        setRepositoryEventDispatcher( repositoryEventDispatcher );
+    }
+
     public void initService( ServiceLocator locator )
     {
-        setLogger( locator.getService( Logger.class ) );
+        setLoggerFactory( locator.getService( LoggerFactory.class ) );
         setMetadataResolver( locator.getService( MetadataResolver.class ) );
         setSyncContextFactory( locator.getService( SyncContextFactory.class ) );
         setRepositoryEventDispatcher( locator.getService( RepositoryEventDispatcher.class ) );
     }
 
-    public DefaultVersionResolver setLogger( Logger logger )
+    public DefaultVersionResolver setLoggerFactory( LoggerFactory loggerFactory )
     {
-        this.logger = ( logger != null ) ? logger : NullLogger.INSTANCE;
+        this.logger = NullLoggerFactory.getSafeLogger( loggerFactory, getClass() );
         return this;
     }
 
+    void setLogger( LoggerFactory loggerFactory )
+    {
+        // plexus support
+        setLoggerFactory( loggerFactory );
+    }
+
     public DefaultVersionResolver setMetadataResolver( MetadataResolver metadataResolver )
     {
-        if ( metadataResolver == null )
-        {
-            throw new IllegalArgumentException( "metadata resolver has not been specified" );
-        }
-        this.metadataResolver = metadataResolver;
+        this.metadataResolver = Validate.notNull( metadataResolver, "metadataResolver cannot be null" );
         return this;
     }
 
     public DefaultVersionResolver setSyncContextFactory( SyncContextFactory syncContextFactory )
     {
-        if ( syncContextFactory == null )
-        {
-            throw new IllegalArgumentException( "sync context factory has not been specified" );
-        }
-        this.syncContextFactory = syncContextFactory;
+        this.syncContextFactory = Validate.notNull( syncContextFactory, "syncContextFactory cannot be null" );
         return this;
     }
 
     public DefaultVersionResolver setRepositoryEventDispatcher( RepositoryEventDispatcher repositoryEventDispatcher )
     {
-        if ( repositoryEventDispatcher == null )
-        {
-            throw new IllegalArgumentException( "repository event dispatcher has not been specified" );
-        }
-        this.repositoryEventDispatcher = repositoryEventDispatcher;
+        this.repositoryEventDispatcher = Validate.notNull( repositoryEventDispatcher,
+            "repositoryEventDispatcher cannot be null" );
         return this;
     }
 
     public VersionResult resolveVersion( RepositorySystemSession session, VersionRequest request )
         throws VersionResolutionException
     {
-        RequestTrace trace = DefaultRequestTrace.newChild( request.getTrace(), request );
+        RequestTrace trace = RequestTrace.newChild( request.getTrace(), request );
 
         Artifact artifact = request.getArtifact();
 
@@ -153,7 +167,7 @@ public class DefaultVersionResolver
 
         Key cacheKey = null;
         RepositoryCache cache = session.getCache();
-        if ( cache != null && !ConfigurationProperties.get( session, "aether.versionResolver.noCache", false ) )
+        if ( cache != null && !ConfigUtils.getBoolean( session, false, "aether.versionResolver.noCache" ) )
         {
             cacheKey = new Key( session, request );
 
@@ -162,8 +176,8 @@ public class DefaultVersionResolver
             {
                 Record record = (Record) obj;
                 result.setVersion( record.version );
-                result.setRepository( CacheUtils.getRepository( session, request.getRepositories(), record.repoClass,
-                                                                record.repoId ) );
+                result.setRepository(
+                    CacheUtils.getRepository( session, request.getRepositories(), record.repoClass, record.repoId ) );
                 return result;
             }
         }
@@ -172,15 +186,13 @@ public class DefaultVersionResolver
 
         if ( RELEASE.equals( version ) )
         {
-            metadata =
-                new DefaultMetadata( artifact.getGroupId(), artifact.getArtifactId(), MAVEN_METADATA_XML,
-                                     Metadata.Nature.RELEASE );
+            metadata = new DefaultMetadata( artifact.getGroupId(), artifact.getArtifactId(), MAVEN_METADATA_XML,
+                                            Metadata.Nature.RELEASE );
         }
         else if ( LATEST.equals( version ) )
         {
-            metadata =
-                new DefaultMetadata( artifact.getGroupId(), artifact.getArtifactId(), MAVEN_METADATA_XML,
-                                     Metadata.Nature.RELEASE_OR_SNAPSHOT );
+            metadata = new DefaultMetadata( artifact.getGroupId(), artifact.getArtifactId(), MAVEN_METADATA_XML,
+                                            Metadata.Nature.RELEASE_OR_SNAPSHOT );
         }
         else if ( version.endsWith( SNAPSHOT ) )
         {
@@ -208,9 +220,9 @@ public class DefaultVersionResolver
         }
         else
         {
-            List<MetadataRequest> metadataRequests = new ArrayList<MetadataRequest>( request.getRepositories().size() );
+            List<MetadataRequest> metadataReqs = new ArrayList<>( request.getRepositories().size() );
 
-            metadataRequests.add( new MetadataRequest( metadata, null, request.getRequestContext() ) );
+            metadataReqs.add( new MetadataRequest( metadata, null, request.getRequestContext() ) );
 
             for ( RemoteRepository repository : request.getRepositories() )
             {
@@ -219,12 +231,12 @@ public class DefaultVersionResolver
                 metadataRequest.setDeleteLocalCopyIfMissing( true );
                 metadataRequest.setFavorLocalRepository( true );
                 metadataRequest.setTrace( trace );
-                metadataRequests.add( metadataRequest );
+                metadataReqs.add( metadataRequest );
             }
 
-            List<MetadataResult> metadataResults = metadataResolver.resolveMetadata( session, metadataRequests );
+            List<MetadataResult> metadataResults = metadataResolver.resolveMetadata( session, metadataReqs );
 
-            Map<String, VersionInfo> infos = new HashMap<String, VersionInfo>();
+            Map<String, VersionInfo> infos = new HashMap<>();
 
             for ( MetadataResult metadataResult : metadataResults )
             {
@@ -236,8 +248,8 @@ public class DefaultVersionResolver
                     repository = session.getLocalRepository();
                 }
 
-                Versioning versioning = readVersions( session, trace, metadataResult.getMetadata(), repository, result );
-                merge( artifact, infos, versioning, repository );
+                Versioning v = readVersions( session, trace, metadataResult.getMetadata(), repository, result );
+                merge( artifact, infos, v, repository );
             }
 
             if ( RELEASE.equals( version ) )
@@ -257,7 +269,8 @@ public class DefaultVersionResolver
                     subRequest.setArtifact( artifact.setVersion( result.getVersion() ) );
                     if ( result.getRepository() instanceof RemoteRepository )
                     {
-                        subRequest.setRepositories( Collections.singletonList( (RemoteRepository) result.getRepository() ) );
+                        RemoteRepository r = (RemoteRepository) result.getRepository();
+                        subRequest.setRepositories( Collections.singletonList( r ) );
                     }
                     else
                     {
@@ -317,9 +330,8 @@ public class DefaultVersionResolver
         {
             if ( metadata != null )
             {
-                SyncContext syncContext = syncContextFactory.newInstance( session, true );
 
-                try
+                try ( SyncContext syncContext = syncContextFactory.newInstance( session, true ) )
                 {
                     syncContext.acquire( null, Collections.singleton( metadata ) );
 
@@ -347,16 +359,12 @@ public class DefaultVersionResolver
                                 versioning = repaired;
 
                                 throw new IOException( "Snapshot information corrupted with remote repository data"
-                                    + ", please verify that no remote repository uses the id '" + repository.getId()
-                                    + "'" );
+                                                           + ", please verify that no remote repository uses the id '"
+                                                           + repository.getId() + "'" );
                             }
                         }
                     }
                 }
-                finally
-                {
-                    syncContext.release();
-                }
             }
         }
         catch ( Exception e )
@@ -375,12 +383,13 @@ public class DefaultVersionResolver
     private void invalidMetadata( RepositorySystemSession session, RequestTrace trace, Metadata metadata,
                                   ArtifactRepository repository, Exception exception )
     {
-        DefaultRepositoryEvent event = new DefaultRepositoryEvent( EventType.METADATA_INVALID, session, trace );
+        RepositoryEvent.Builder event = new RepositoryEvent.Builder( session, EventType.METADATA_INVALID );
+        event.setTrace( trace );
         event.setMetadata( metadata );
         event.setException( exception );
         event.setRepository( repository );
 
-        repositoryEventDispatcher.dispatch( event );
+        repositoryEventDispatcher.dispatch( event.build() );
     }
 
     private void merge( Artifact artifact, Map<String, VersionInfo> infos, Versioning versioning,
@@ -440,8 +449,8 @@ public class DefaultVersionResolver
         VersionInfo srcInfo = infos.get( srcKey );
         VersionInfo dstInfo = infos.get( dstKey );
 
-        if ( dstInfo == null
-            || ( srcInfo != null && dstInfo.isOutdated( srcInfo.timestamp ) && srcInfo.repository != dstInfo.repository ) )
+        if ( dstInfo == null || ( srcInfo != null && dstInfo.isOutdated( srcInfo.timestamp )
+            && srcInfo.repository != dstInfo.repository ) )
         {
             infos.put( dstKey, srcInfo );
         }
@@ -526,7 +535,7 @@ public class DefaultVersionResolver
             version = artifact.getVersion();
             localRepo = session.getLocalRepository().getBasedir();
             workspace = CacheUtils.getWorkspace( session );
-            repositories = new ArrayList<RemoteRepository>( request.getRepositories().size() );
+            repositories = new ArrayList<>( request.getRepositories().size() );
             boolean repoMan = false;
             for ( RemoteRepository repository : request.getRepositories() )
             {
@@ -566,10 +575,10 @@ public class DefaultVersionResolver
             }
 
             Key that = (Key) obj;
-            return artifactId.equals( that.artifactId ) && groupId.equals( that.groupId )
-                && classifier.equals( that.classifier ) && extension.equals( that.extension )
-                && version.equals( that.version ) && context.equals( that.context )
-                && localRepo.equals( that.localRepo ) && CacheUtils.eq( workspace, that.workspace )
+            return artifactId.equals( that.artifactId ) && groupId.equals( that.groupId ) && classifier.equals(
+                that.classifier ) && extension.equals( that.extension ) && version.equals( that.version )
+                && context.equals( that.context ) && localRepo.equals( that.localRepo )
+                && CacheUtils.eq( workspace, that.workspace )
                 && CacheUtils.repositoriesEquals( repositories, that.repositories );
         }
 
@@ -605,4 +614,4 @@ public class DefaultVersionResolver
         }
     }
 
-}
+}
\ No newline at end of file
