@@ -1,18 +1,22 @@
 package org.apache.maven.artifact.resolver;
 
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
- * agreements. See the NOTICE file distributed with this work for additional information regarding
- * copyright ownership. The ASF licenses this file to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance with the License. You may obtain a
- * copy of the License at
- * 
- * http://www.apache.org/licenses/LICENSE-2.0
- * 
- * Unless required by applicable law or agreed to in writing, software distributed under the License
- * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
- * or implied. See the License for the specific language governing permissions and limitations under
- * the License.
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *  http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 
 import java.io.File;
@@ -56,20 +60,21 @@ import org.codehaus.plexus.component.annotations.Component;
 import org.codehaus.plexus.component.annotations.Requirement;
 import org.codehaus.plexus.component.repository.exception.ComponentLookupException;
 import org.codehaus.plexus.logging.Logger;
-import org.sonatype.aether.RepositorySystem;
-import org.sonatype.aether.RepositorySystemSession;
-import org.sonatype.aether.repository.LocalRepositoryManager;
-import org.sonatype.aether.resolution.ArtifactRequest;
-import org.sonatype.aether.resolution.ArtifactResult;
+import org.codehaus.plexus.personality.plexus.lifecycle.phase.Disposable;
+import org.eclipse.aether.RepositorySystem;
+import org.eclipse.aether.RepositorySystemSession;
+import org.eclipse.aether.repository.LocalRepositoryManager;
+import org.eclipse.aether.resolution.ArtifactRequest;
+import org.eclipse.aether.resolution.ArtifactResult;
 
 /**
  * @author Jason van Zyl
  */
-@Component(role = ArtifactResolver.class)
+@Component( role = ArtifactResolver.class )
 public class DefaultArtifactResolver
-    implements ArtifactResolver
+    implements ArtifactResolver, Disposable
 {
-    @Requirement 
+    @Requirement
     private Logger logger;
 
     @Requirement
@@ -83,7 +88,7 @@ public class DefaultArtifactResolver
 
     @Requirement
     private ArtifactMetadataSource source;
-    
+
     @Requirement
     private PlexusContainer container;
 
@@ -97,7 +102,7 @@ public class DefaultArtifactResolver
 
     public DefaultArtifactResolver()
     {
-        int threads = Integer.getInteger( "maven.artifact.threads", 5 ).intValue();
+        int threads = Integer.getInteger( "maven.artifact.threads", 5 );
         if ( threads <= 1 )
         {
             executor = new Executor()
@@ -110,24 +115,15 @@ public class DefaultArtifactResolver
         }
         else
         {
-            executor =
-                new ThreadPoolExecutor( threads, threads, 3, TimeUnit.SECONDS, new LinkedBlockingQueue<Runnable>(), new DaemonThreadCreator());
-        }
-    }
-
-    @Override
-    protected void finalize()
-        throws Throwable
-    {
-        if ( executor instanceof ExecutorService )
-        {
-            ( (ExecutorService) executor ).shutdown();
+            executor = new ThreadPoolExecutor( threads, threads, 3, TimeUnit.SECONDS,
+                                               new LinkedBlockingQueue<Runnable>(), new DaemonThreadCreator() );
         }
     }
 
     private RepositorySystemSession getSession( ArtifactRepository localRepository )
     {
-        return LegacyLocalRepositoryManager.overlay( localRepository, legacySupport.getRepositorySession(), repoSystem );
+        return LegacyLocalRepositoryManager.overlay( localRepository, legacySupport.getRepositorySession(),
+                                                     repoSystem );
     }
 
     private void injectSession1( RepositoryRequest request, MavenSession session )
@@ -151,47 +147,53 @@ public class DefaultArtifactResolver
         }
     }
 
-    public void resolve( Artifact artifact, List<ArtifactRepository> remoteRepositories, ArtifactRepository localRepository, TransferListener resolutionListener )
-        throws ArtifactResolutionException, ArtifactNotFoundException
+    public void resolve( Artifact artifact, List<ArtifactRepository> remoteRepositories,
+                         ArtifactRepository localRepository, TransferListener resolutionListener )
+                             throws ArtifactResolutionException, ArtifactNotFoundException
     {
         resolve( artifact, remoteRepositories, getSession( localRepository ) );
     }
 
-    public void resolveAlways( Artifact artifact, List<ArtifactRepository> remoteRepositories, ArtifactRepository localRepository )
-        throws ArtifactResolutionException, ArtifactNotFoundException
+    public void resolveAlways( Artifact artifact, List<ArtifactRepository> remoteRepositories,
+                               ArtifactRepository localRepository )
+                                   throws ArtifactResolutionException, ArtifactNotFoundException
     {
         resolve( artifact, remoteRepositories, getSession( localRepository ) );
     }
 
-    private void resolve( Artifact artifact, List<ArtifactRepository> remoteRepositories, RepositorySystemSession session )
-        throws ArtifactResolutionException, ArtifactNotFoundException
+    private void resolve( Artifact artifact, List<ArtifactRepository> remoteRepositories,
+                          RepositorySystemSession session )
+                              throws ArtifactResolutionException, ArtifactNotFoundException
     {
         if ( artifact == null )
         {
             return;
         }
-        
+
         if ( Artifact.SCOPE_SYSTEM.equals( artifact.getScope() ) )
         {
             File systemFile = artifact.getFile();
 
             if ( systemFile == null )
             {
-                throw new ArtifactNotFoundException( "System artifact: " + artifact + " has no file attached", artifact );
+                throw new ArtifactNotFoundException( "System artifact: " + artifact + " has no file attached",
+                                                     artifact );
             }
 
             if ( !systemFile.exists() )
             {
-                throw new ArtifactNotFoundException( "System artifact: " + artifact + " not found in path: " + systemFile, artifact );
+                throw new ArtifactNotFoundException( "System artifact: " + artifact + " not found in path: "
+                    + systemFile, artifact );
             }
 
             if ( !systemFile.isFile() )
             {
-                throw new ArtifactNotFoundException( "System artifact: " + artifact + " is not a file: " + systemFile, artifact );
+                throw new ArtifactNotFoundException( "System artifact: " + artifact + " is not a file: " + systemFile,
+                                                     artifact );
             }
 
             artifact.setResolved( true );
-            
+
             return;
         }
 
@@ -212,9 +214,9 @@ public class DefaultArtifactResolver
 
                 result = repoSystem.resolveArtifact( session, artifactRequest );
             }
-            catch ( org.sonatype.aether.resolution.ArtifactResolutionException e )
+            catch ( org.eclipse.aether.resolution.ArtifactResolutionException e )
             {
-                if ( e.getCause() instanceof org.sonatype.aether.transfer.ArtifactNotFoundException )
+                if ( e.getCause() instanceof org.eclipse.aether.transfer.ArtifactNotFoundException )
                 {
                     throw new ArtifactNotFoundException( e.getMessage(), artifact, remoteRepositories, e );
                 }
@@ -249,65 +251,91 @@ public class DefaultArtifactResolver
         }
     }
 
-    public ArtifactResolutionResult resolveTransitively( Set<Artifact> artifacts, Artifact originatingArtifact, ArtifactRepository localRepository, List<ArtifactRepository> remoteRepositories,
+    public ArtifactResolutionResult resolveTransitively( Set<Artifact> artifacts, Artifact originatingArtifact,
+                                                         ArtifactRepository localRepository,
+                                                         List<ArtifactRepository> remoteRepositories,
                                                          ArtifactMetadataSource source, ArtifactFilter filter )
-        throws ArtifactResolutionException, ArtifactNotFoundException
+                                                             throws ArtifactResolutionException,
+                                                             ArtifactNotFoundException
     {
-        return resolveTransitively( artifacts, originatingArtifact, Collections.EMPTY_MAP, localRepository, remoteRepositories, source, filter );
+        return resolveTransitively( artifacts, originatingArtifact, Collections.EMPTY_MAP, localRepository,
+                                    remoteRepositories, source, filter );
 
     }
 
-    public ArtifactResolutionResult resolveTransitively( Set<Artifact> artifacts, Artifact originatingArtifact, Map managedVersions, ArtifactRepository localRepository,
-                                                         List<ArtifactRepository> remoteRepositories, ArtifactMetadataSource source )
-        throws ArtifactResolutionException, ArtifactNotFoundException
-    {
-        return resolveTransitively( artifacts, originatingArtifact, managedVersions, localRepository, remoteRepositories, source, null );
-    }
-
-    public ArtifactResolutionResult resolveTransitively( Set<Artifact> artifacts, Artifact originatingArtifact, Map managedVersions, ArtifactRepository localRepository,
-                                                         List<ArtifactRepository> remoteRepositories, ArtifactMetadataSource source, ArtifactFilter filter )
-        throws ArtifactResolutionException, ArtifactNotFoundException
-    {
-        return resolveTransitively( artifacts, originatingArtifact, managedVersions, localRepository, remoteRepositories, source, filter, null );
-    }
-
-    public ArtifactResolutionResult resolveTransitively( Set<Artifact> artifacts, Artifact originatingArtifact, List<ArtifactRepository> remoteRepositories, ArtifactRepository localRepository,
+    public ArtifactResolutionResult resolveTransitively( Set<Artifact> artifacts, Artifact originatingArtifact,
+                                                         Map<String, Artifact> managedVersions,
+                                                         ArtifactRepository localRepository,
+                                                         List<ArtifactRepository> remoteRepositories,
                                                          ArtifactMetadataSource source )
-        throws ArtifactResolutionException, ArtifactNotFoundException
+                                                             throws ArtifactResolutionException,
+                                                             ArtifactNotFoundException
+    {
+        return resolveTransitively( artifacts, originatingArtifact, managedVersions, localRepository,
+                                    remoteRepositories, source, null );
+    }
+
+    public ArtifactResolutionResult resolveTransitively( Set<Artifact> artifacts, Artifact originatingArtifact,
+                                                         Map<String, Artifact> managedVersions,
+                                                         ArtifactRepository localRepository,
+                                                         List<ArtifactRepository> remoteRepositories,
+                                                         ArtifactMetadataSource source, ArtifactFilter filter )
+                                                             throws ArtifactResolutionException,
+                                                             ArtifactNotFoundException
+    {
+        return resolveTransitively( artifacts, originatingArtifact, managedVersions, localRepository,
+                                    remoteRepositories, source, filter, null );
+    }
+
+    public ArtifactResolutionResult resolveTransitively( Set<Artifact> artifacts, Artifact originatingArtifact,
+                                                         List<ArtifactRepository> remoteRepositories,
+                                                         ArtifactRepository localRepository,
+                                                         ArtifactMetadataSource source )
+                                                             throws ArtifactResolutionException,
+                                                             ArtifactNotFoundException
     {
         return resolveTransitively( artifacts, originatingArtifact, localRepository, remoteRepositories, source, null );
     }
 
-    public ArtifactResolutionResult resolveTransitively( Set<Artifact> artifacts, Artifact originatingArtifact, List<ArtifactRepository> remoteRepositories, ArtifactRepository localRepository,
-                                                         ArtifactMetadataSource source, List<ResolutionListener> listeners )
-        throws ArtifactResolutionException, ArtifactNotFoundException
+    public ArtifactResolutionResult resolveTransitively( Set<Artifact> artifacts, Artifact originatingArtifact,
+                                                         List<ArtifactRepository> remoteRepositories,
+                                                         ArtifactRepository localRepository,
+                                                         ArtifactMetadataSource source,
+                                                         List<ResolutionListener> listeners )
+                                                             throws ArtifactResolutionException,
+                                                             ArtifactNotFoundException
     {
         return resolveTransitively( artifacts, originatingArtifact, Collections.EMPTY_MAP, localRepository,
                                     remoteRepositories, source, null, listeners );
     }
 
-    public ArtifactResolutionResult resolveTransitively( Set<Artifact> artifacts, Artifact originatingArtifact, Map managedVersions, ArtifactRepository localRepository,
-                                                         List<ArtifactRepository> remoteRepositories, ArtifactMetadataSource source, ArtifactFilter filter, List<ResolutionListener> listeners )
-        throws ArtifactResolutionException, ArtifactNotFoundException
+    public ArtifactResolutionResult resolveTransitively( Set<Artifact> artifacts, Artifact originatingArtifact,
+                                                         Map<String, Artifact> managedVersions,
+                                                         ArtifactRepository localRepository,
+                                                         List<ArtifactRepository> remoteRepositories,
+                                                         ArtifactMetadataSource source, ArtifactFilter filter,
+                                                         List<ResolutionListener> listeners )
+                                                             throws ArtifactResolutionException,
+                                                             ArtifactNotFoundException
     {
-        return resolveTransitively( artifacts, originatingArtifact, managedVersions, localRepository, remoteRepositories, source, filter, listeners, null );
+        return resolveTransitively( artifacts, originatingArtifact, managedVersions, localRepository,
+                                    remoteRepositories, source, filter, listeners, null );
     }
 
-    public ArtifactResolutionResult resolveTransitively( Set<Artifact> artifacts, Artifact originatingArtifact, Map managedVersions, ArtifactRepository localRepository,
-                                                         List<ArtifactRepository> remoteRepositories, ArtifactMetadataSource source, ArtifactFilter filter, List<ResolutionListener> listeners,
+    public ArtifactResolutionResult resolveTransitively( Set<Artifact> artifacts, Artifact originatingArtifact,
+                                                         Map<String, Artifact> managedVersions,
+                                                         ArtifactRepository localRepository,
+                                                         List<ArtifactRepository> remoteRepositories,
+                                                         ArtifactMetadataSource source, ArtifactFilter filter,
+                                                         List<ResolutionListener> listeners,
                                                          List<ConflictResolver> conflictResolvers )
-        throws ArtifactResolutionException, ArtifactNotFoundException
+                                                             throws ArtifactResolutionException,
+                                                             ArtifactNotFoundException
     {
-        ArtifactResolutionRequest request = new ArtifactResolutionRequest()
-            .setArtifact( originatingArtifact )
-            .setResolveRoot( false )
+        ArtifactResolutionRequest request =
+            new ArtifactResolutionRequest().setArtifact( originatingArtifact ).setResolveRoot( false )
             // This is required by the surefire plugin
-            .setArtifactDependencies( artifacts )            
-            .setManagedVersionMap( managedVersions )
-            .setLocalRepository( localRepository )
-            .setRemoteRepositories( remoteRepositories )
-            .setCollectionFilter( filter )
-            .setListeners( listeners );
+            .setArtifactDependencies( artifacts ).setManagedVersionMap( managedVersions ).setLocalRepository( localRepository ).setRemoteRepositories( remoteRepositories ).setCollectionFilter( filter ).setListeners( listeners );
 
         injectSession2( request, legacySupport.getSession() );
 
@@ -336,13 +364,14 @@ public class DefaultArtifactResolver
     {
         Artifact rootArtifact = request.getArtifact();
         Set<Artifact> artifacts = request.getArtifactDependencies();
-        Map managedVersions = request.getManagedVersionMap();
+        Map<String, Artifact> managedVersions = request.getManagedVersionMap();
         List<ResolutionListener> listeners = request.getListeners();
-        ArtifactFilter collectionFilter = request.getCollectionFilter();                       
+        ArtifactFilter collectionFilter = request.getCollectionFilter();
         ArtifactFilter resolutionFilter = request.getResolutionFilter();
         RepositorySystemSession session = getSession( request.getLocalRepository() );
-        
-        //TODO: hack because metadata isn't generated in m2e correctly and i want to run the maven i have in the workspace
+
+        // TODO: hack because metadata isn't generated in m2e correctly and i want to run the maven i have in the
+        // workspace
         if ( source == null )
         {
             try
@@ -357,7 +386,7 @@ public class DefaultArtifactResolver
 
         if ( listeners == null )
         {
-            listeners = new ArrayList<ResolutionListener>();
+            listeners = new ArrayList<>();
 
             if ( logger.isDebugEnabled() )
             {
@@ -373,9 +402,9 @@ public class DefaultArtifactResolver
         // This is often an artifact like a POM that is taken from disk and we already have hold of the
         // file reference. But this may be a Maven Plugin that we need to resolve from a remote repository
         // as well as its dependencies.
-                        
+
         if ( request.isResolveRoot() /* && rootArtifact.getFile() == null */ )
-        {            
+        {
             try
             {
                 resolve( rootArtifact, request.getRemoteRepositories(), session );
@@ -418,11 +447,11 @@ public class DefaultArtifactResolver
                 }
                 else
                 {
-                    List<Artifact> allArtifacts = new ArrayList<Artifact>();
+                    List<Artifact> allArtifacts = new ArrayList<>();
                     allArtifacts.addAll( artifacts );
                     allArtifacts.addAll( directArtifacts );
 
-                    Map<String, Artifact> mergedArtifacts = new LinkedHashMap<String, Artifact>();
+                    Map<String, Artifact> mergedArtifacts = new LinkedHashMap<>();
                     for ( Artifact artifact : allArtifacts )
                     {
                         String conflictId = artifact.getDependencyConflictId();
@@ -432,7 +461,7 @@ public class DefaultArtifactResolver
                         }
                     }
 
-                    artifacts = new LinkedHashSet<Artifact>( mergedArtifacts.values() );
+                    artifacts = new LinkedHashSet<>( mergedArtifacts.values() );
                 }
 
                 collectionRequest = new ArtifactResolutionRequest( request );
@@ -450,7 +479,7 @@ public class DefaultArtifactResolver
                 return result;
             }
         }
-        
+
         if ( artifacts == null || artifacts.isEmpty() )
         {
             if ( request.isResolveRoot() )
@@ -458,18 +487,18 @@ public class DefaultArtifactResolver
                 result.addArtifact( rootArtifact );
             }
             return result;
-        } 
+        }
 
         // After the collection we will have the artifact object in the result but they will not be resolved yet.
-        result =
-            artifactCollector.collect( artifacts, rootArtifact, managedVersions, collectionRequest, source,
-                                       collectionFilter, listeners, null );
-                        
+        result = artifactCollector.collect( artifacts, rootArtifact, managedVersions, collectionRequest, source,
+                                            collectionFilter, listeners, null );
+
         // We have metadata retrieval problems, or there are cycles that have been detected
         // so we give this back to the calling code and let them deal with this information
         // appropriately.
 
-        if ( result.hasMetadataResolutionExceptions() || result.hasVersionRangeViolations() || result.hasCircularDependencyExceptions() )
+        if ( result.hasMetadataResolutionExceptions() || result.hasVersionRangeViolations()
+            || result.hasCircularDependencyExceptions() )
         {
             return result;
         }
@@ -508,19 +537,20 @@ public class DefaultArtifactResolver
         // We want to send the root artifact back in the result but we need to do this after the other dependencies
         // have been resolved.
         if ( request.isResolveRoot() )
-        {            
+        {
             // Add the root artifact (as the first artifact to retain logical order of class path!)
-            Set<Artifact> allArtifacts = new LinkedHashSet<Artifact>();
+            Set<Artifact> allArtifacts = new LinkedHashSet<>();
             allArtifacts.add( rootArtifact );
             allArtifacts.addAll( result.getArtifacts() );
             result.setArtifacts( allArtifacts );
-        }                        
-                 
+        }
+
         return result;
     }
 
-    public void resolve( Artifact artifact, List<ArtifactRepository> remoteRepositories, ArtifactRepository localRepository )
-        throws ArtifactResolutionException, ArtifactNotFoundException
+    public void resolve( Artifact artifact, List<ArtifactRepository> remoteRepositories,
+                         ArtifactRepository localRepository )
+                             throws ArtifactResolutionException, ArtifactNotFoundException
     {
         resolve( artifact, remoteRepositories, localRepository, null );
     }
@@ -528,19 +558,20 @@ public class DefaultArtifactResolver
     /**
      * ThreadCreator for creating daemon threads with fixed ThreadGroup-name.
      */
-    final static class DaemonThreadCreator
+    static final class DaemonThreadCreator
         implements ThreadFactory
     {
         static final String THREADGROUP_NAME = "org.apache.maven.artifact.resolver.DefaultArtifactResolver";
 
-        final static ThreadGroup group = new ThreadGroup( THREADGROUP_NAME );
+        static final ThreadGroup GROUP = new ThreadGroup( THREADGROUP_NAME );
 
-        final static AtomicInteger threadNumber = new AtomicInteger( 1 );
+        static final AtomicInteger THREAD_NUMBER = new AtomicInteger( 1 );
 
         public Thread newThread( Runnable r )
         {
-            Thread newThread = new Thread( group, r, "resolver-" + threadNumber.getAndIncrement() );
+            Thread newThread = new Thread( GROUP, r, "resolver-" + THREAD_NUMBER.getAndIncrement() );
             newThread.setDaemon( true );
+            newThread.setContextClassLoader( null );
             return newThread;
         }
     }
@@ -561,8 +592,9 @@ public class DefaultArtifactResolver
 
         private final ArtifactResolutionResult result;
 
-        public ResolveTask( ClassLoader classLoader, CountDownLatch latch, Artifact artifact, RepositorySystemSession session,
-                            List<ArtifactRepository> remoteRepositories, ArtifactResolutionResult result )
+        public ResolveTask( ClassLoader classLoader, CountDownLatch latch, Artifact artifact,
+                            RepositorySystemSession session, List<ArtifactRepository> remoteRepositories,
+                            ArtifactResolutionResult result )
         {
             this.classLoader = classLoader;
             this.latch = latch;
@@ -574,6 +606,7 @@ public class DefaultArtifactResolver
 
         public void run()
         {
+            ClassLoader old = Thread.currentThread().getContextClassLoader();
             try
             {
                 Thread.currentThread().setContextClassLoader( classLoader );
@@ -602,9 +635,20 @@ public class DefaultArtifactResolver
             finally
             {
                 latch.countDown();
+                Thread.currentThread().setContextClassLoader( old );
+
             }
         }
 
     }
 
+    @Override
+    public void dispose()
+    {
+        if ( executor instanceof ExecutorService )
+        {
+            ( (ExecutorService) executor ).shutdownNow();
+        }
+    }
+
 }
