@@ -63,10 +63,10 @@ import org.codehaus.plexus.logging.Logger;
 public class DefaultLegacyArtifactCollector
     implements LegacyArtifactCollector
 {
-	@Requirement(hint="nearest")
+    @Requirement( hint = "nearest" )
     private ConflictResolver defaultConflictResolver;
 
-	@Requirement
+    @Requirement
     private Logger logger;
 
     @Requirement
@@ -87,7 +87,7 @@ public class DefaultLegacyArtifactCollector
     }
 
     public ArtifactResolutionResult collect( Set<Artifact> artifacts, Artifact originatingArtifact,
-                                             Map managedVersions, ArtifactRepository localRepository,
+                                             Map<String, Artifact> managedVersions, ArtifactRepository localRepository,
                                              List<ArtifactRepository> remoteRepositories,
                                              ArtifactMetadataSource source, ArtifactFilter filter,
                                              List<ResolutionListener> listeners,
@@ -102,7 +102,7 @@ public class DefaultLegacyArtifactCollector
     }
 
     public ArtifactResolutionResult collect( Set<Artifact> artifacts, Artifact originatingArtifact,
-                                             Map managedVersions, ArtifactResolutionRequest repositoryRequest,
+                                             Map<String, Artifact> managedVersions, ArtifactResolutionRequest repositoryRequest,
                                              ArtifactMetadataSource source, ArtifactFilter filter,
                                              List<ResolutionListener> listeners,
                                              List<ConflictResolver> conflictResolvers )
@@ -116,7 +116,7 @@ public class DefaultLegacyArtifactCollector
             conflictResolvers = Collections.singletonList( defaultConflictResolver );
         }
 
-        Map<Object, List<ResolutionNode>> resolvedArtifacts = new LinkedHashMap<Object, List<ResolutionNode>>();
+        Map<Object, List<ResolutionNode>> resolvedArtifacts = new LinkedHashMap<>();
 
         ResolutionNode root = new ResolutionNode( originatingArtifact, repositoryRequest.getRemoteRepositories() );
 
@@ -160,7 +160,7 @@ public class DefaultLegacyArtifactCollector
             result.addErrorArtifactException( e );
         }
 
-        Set<ResolutionNode> set = new LinkedHashSet<ResolutionNode>();
+        Set<ResolutionNode> set = new LinkedHashSet<>();
 
         for ( List<ResolutionNode> nodes : resolvedArtifacts.values() )
         {
@@ -206,7 +206,7 @@ public class DefaultLegacyArtifactCollector
      * @param originatingArtifact artifact we are processing
      * @param managedVersions original managed versions
      */
-    private ManagedVersionMap getManagedVersionsMap( Artifact originatingArtifact, Map managedVersions )
+    private ManagedVersionMap getManagedVersionsMap( Artifact originatingArtifact, Map<String,Artifact> managedVersions )
     {
         ManagedVersionMap versionMap;
         if ( ( managedVersions != null ) && ( managedVersions instanceof ManagedVersionMap ) )
@@ -219,7 +219,7 @@ public class DefaultLegacyArtifactCollector
         }
 
         /* remove the originating artifact if it is also in managed versions to avoid being modified during resolution */
-        Artifact managedOriginatingArtifact = (Artifact) versionMap.get( originatingArtifact.getDependencyConflictId() );
+        Artifact managedOriginatingArtifact = versionMap.get( originatingArtifact.getDependencyConflictId() );
 
         if ( managedOriginatingArtifact != null )
         {
@@ -342,9 +342,9 @@ public class DefaultLegacyArtifactCollector
 
                         // Conflict Resolution
                         ResolutionNode resolved = null;
-                        for ( Iterator j = conflictResolvers.iterator(); ( resolved == null ) && j.hasNext(); )
+                        for ( Iterator<ConflictResolver> j = conflictResolvers.iterator(); ( resolved == null ) && j.hasNext(); )
                         {
-                            ConflictResolver conflictResolver = (ConflictResolver) j.next();
+                            ConflictResolver conflictResolver = j.next();
 
                             resolved = conflictResolver.resolveConflict( previous, node );
                         }
@@ -406,7 +406,7 @@ public class DefaultLegacyArtifactCollector
         }
         else
         {
-            previousNodes = new ArrayList<ResolutionNode>();
+            previousNodes = new ArrayList<>();
 
             resolvedArtifacts.put( key, previousNodes );
         }
@@ -424,9 +424,9 @@ public class DefaultLegacyArtifactCollector
 
             Artifact parentArtifact = node.getArtifact();
 
-            for ( Iterator i = node.getChildrenIterator(); i.hasNext(); )
+            for ( Iterator<ResolutionNode> i = node.getChildrenIterator(); i.hasNext(); )
             {
-                ResolutionNode child = (ResolutionNode) i.next();
+                ResolutionNode child = i.next();
 
                 try
                 {
@@ -465,7 +465,7 @@ public class DefaultLegacyArtifactCollector
                                     // added to the artifact before we retrive the metadata
                                     // for the artifact; otherwise we may end up with unwanted
                                     // dependencies.
-                                    Artifact ma = (Artifact) managedVersions.get( childKey );
+                                    Artifact ma = managedVersions.get( childKey );
                                     ArtifactFilter managedExclusionFilter = ma.getDependencyFilter();
                                     if ( null != managedExclusionFilter )
                                     {
@@ -602,7 +602,7 @@ public class DefaultLegacyArtifactCollector
     private void manageArtifact( ResolutionNode node, ManagedVersionMap managedVersions,
                                  List<ResolutionListener> listeners )
     {
-        Artifact artifact = (Artifact) managedVersions.get( node.getKey() );
+        Artifact artifact = managedVersions.get( node.getKey() );
 
         // Before we update the version of the artifact, we need to know
         // whether we are working on a transitive dependency or not. This
@@ -674,8 +674,8 @@ public class DefaultLegacyArtifactCollector
             fireEvent( ResolutionListener.UPDATE_SCOPE, listeners, nearest, farthestArtifact );
 
             // previously we cloned the artifact, but it is more effecient to just update the artifactScope
-            // if problems are later discovered that the original object needs its original artifactScope value, cloning
-            // may
+            // if problems are later discovered that the original object needs its original artifactScope value, 
+            // cloning may
             // again be appropriate
             nearestArtifact.setScope( farthestArtifact.getScope() );
         }
@@ -774,7 +774,7 @@ public class DefaultLegacyArtifactCollector
     }
 
     public ArtifactResolutionResult collect( Set<Artifact> artifacts, Artifact originatingArtifact,
-                                             Map managedVersions, ArtifactRepository localRepository,
+                                             Map<String, Artifact> managedVersions, ArtifactRepository localRepository,
                                              List<ArtifactRepository> remoteRepositories,
                                              ArtifactMetadataSource source, ArtifactFilter filter,
                                              List<ResolutionListener> listeners )
