@@ -19,10 +19,7 @@ package org.apache.maven.repository.legacy.resolver.conflict;
  * under the License.
  */
 
-import java.util.Collections;
-
 import org.apache.maven.artifact.resolver.ResolutionNode;
-import org.apache.maven.repository.legacy.resolver.conflict.OldestConflictResolver;
 
 /**
  * Tests <code>OldestConflictResolver</code>.
@@ -52,13 +49,14 @@ public class OldestConflictResolverTest
      */
     public void testDepth()
     {
-        ResolutionNode a1n = new ResolutionNode( a1, Collections.EMPTY_LIST );
-        ResolutionNode b1n = new ResolutionNode( b1, Collections.EMPTY_LIST );
-        ResolutionNode a2n = new ResolutionNode( a2, Collections.EMPTY_LIST, b1n );
+        ResolutionNode a1n = createResolutionNode( a1 );
+        ResolutionNode b1n = createResolutionNode( b1);
+        ResolutionNode a2n = createResolutionNode( a2,  b1n );
 
         assertResolveConflict( a1n, a1n, a2n );
     }
 
+
     /**
      * Tests that <code>a:1.0</code> wins in the scenario:
      * <pre>
@@ -68,9 +66,9 @@ public class OldestConflictResolverTest
      */
     public void testDepthReversed()
     {
-        ResolutionNode b1n = new ResolutionNode( b1, Collections.EMPTY_LIST );
-        ResolutionNode a2n = new ResolutionNode( a2, Collections.EMPTY_LIST, b1n );
-        ResolutionNode a1n = new ResolutionNode( a1, Collections.EMPTY_LIST );
+        ResolutionNode b1n = createResolutionNode( b1 );
+        ResolutionNode a2n = createResolutionNode( a2, b1n );
+        ResolutionNode a1n = createResolutionNode( a1 );
 
         assertResolveConflict( a1n, a2n, a1n );
     }
@@ -84,8 +82,8 @@ public class OldestConflictResolverTest
      */
     public void testEqual()
     {
-        ResolutionNode a1n = new ResolutionNode( a1, Collections.EMPTY_LIST );
-        ResolutionNode a2n = new ResolutionNode( a2, Collections.EMPTY_LIST );
+        ResolutionNode a1n = createResolutionNode( a1 );
+        ResolutionNode a2n = createResolutionNode( a2 );
 
         assertResolveConflict( a1n, a1n, a2n );
     }
@@ -99,8 +97,8 @@ public class OldestConflictResolverTest
      */
     public void testEqualReversed()
     {
-        ResolutionNode a2n = new ResolutionNode( a2, Collections.EMPTY_LIST );
-        ResolutionNode a1n = new ResolutionNode( a1, Collections.EMPTY_LIST );
+        ResolutionNode a2n = createResolutionNode( a2);
+        ResolutionNode a1n = createResolutionNode( a1 );
 
         assertResolveConflict( a1n, a2n, a1n );
     }
