@@ -42,8 +42,8 @@ import org.eclipse.aether.repository.WorkspaceRepository;
 import org.eclipse.aether.util.artifact.ArtifactIdUtils;
 
 /**
- * An implementation of a workspace reader that knows how to search the Maven reactor for artifacts, either
- * as packaged jar if it has been built, or only compile output directory if packaging hasn't happened yet.
+ * An implementation of a workspace reader that knows how to search the Maven reactor for artifacts, either as packaged
+ * jar if it has been built, or only compile output directory if packaging hasn't happened yet.
  *
  * @author Jason van Zyl
  */
@@ -54,7 +54,8 @@ class ReactorReader
 {
     public static final String HINT = "reactor";
 
-    private static final Collection<String> COMPILE_PHASE_TYPES = Arrays.asList( "jar", "ejb-client" );
+    private static final Collection<String> COMPILE_PHASE_TYPES =
+        Arrays.asList( "jar", "ejb-client", "war", "rar", "ejb3", "par", "sar", "wsr", "har", "app-client" );
 
     private Map<String, MavenProject> projectsByGAV;
 
@@ -67,7 +68,7 @@ class ReactorReader
     {
         projectsByGAV = session.getProjectMap();
 
-        projectsByGA = new HashMap<String, List<MavenProject>>( projectsByGAV.size() * 2 );
+        projectsByGA = new HashMap<>( projectsByGAV.size() * 2 );
         for ( MavenProject project : projectsByGAV.values() )
         {
             String key = ArtifactUtils.versionlessKey( project.getGroupId(), project.getArtifactId() );
@@ -76,14 +77,14 @@ class ReactorReader
 
             if ( projects == null )
             {
-                projects = new ArrayList<MavenProject>( 1 );
+                projects = new ArrayList<>( 1 );
                 projectsByGA.put( key, projects );
             }
 
             projects.add( project );
         }
 
-        repository = new WorkspaceRepository( "reactor", new HashSet<String>( projectsByGAV.keySet() ) );
+        repository = new WorkspaceRepository( "reactor", new HashSet<>( projectsByGAV.keySet() ) );
     }
 
     //
@@ -124,7 +125,7 @@ class ReactorReader
             return Collections.emptyList();
         }
 
-        List<String> versions = new ArrayList<String>();
+        List<String> versions = new ArrayList<>();
 
         for ( MavenProject project : projects )
         {
