@@ -22,20 +22,27 @@ package org.apache.maven.execution;
 import java.io.File;
 import java.util.ArrayList;
 import java.util.Date;
+import java.util.HashMap;
 import java.util.List;
+import java.util.Map;
 import java.util.Properties;
 
+import org.apache.commons.lang3.Validate;
 import org.apache.maven.artifact.repository.ArtifactRepository;
+import org.apache.maven.eventspy.internal.EventSpyDispatcher;
 import org.apache.maven.model.Profile;
 import org.apache.maven.project.DefaultProjectBuildingRequest;
 import org.apache.maven.project.ProjectBuildingRequest;
 import org.apache.maven.settings.Mirror;
 import org.apache.maven.settings.Proxy;
 import org.apache.maven.settings.Server;
-import org.sonatype.aether.RepositoryCache;
-import org.sonatype.aether.repository.WorkspaceReader;
-import org.sonatype.aether.transfer.TransferListener;
-import org.sonatype.aether.util.DefaultRepositoryCache;
+import org.apache.maven.toolchain.model.ToolchainModel;
+import org.eclipse.aether.DefaultRepositoryCache;
+import org.eclipse.aether.RepositoryCache;
+import org.eclipse.aether.repository.WorkspaceReader;
+import org.eclipse.aether.transfer.TransferListener;
+
+import com.google.common.collect.Maps;
 
 /**
  * @author Jason van Zyl
@@ -50,6 +57,8 @@ public class DefaultMavenExecutionRequest
 
     private ArtifactRepository localRepository;
 
+    private EventSpyDispatcher eventSpyDispatcher;
+
     private File localRepositoryPath;
 
     private boolean offline = false;
@@ -84,10 +93,14 @@ public class DefaultMavenExecutionRequest
 
     private File userToolchainsFile;
 
+    private File globalToolchainsFile;
+
     // ----------------------------------------------------------------------------
     // Request
     // ----------------------------------------------------------------------------
 
+    private File multiModuleProjectDirectory;
+
     private File basedir;
 
     private List<String> goals;
@@ -102,6 +115,8 @@ public class DefaultMavenExecutionRequest
 
     private List<String> selectedProjects;
 
+    private List<String> excludedProjects;
+
     private String resumeFrom;
 
     private String makeBehavior;
@@ -132,9 +147,11 @@ public class DefaultMavenExecutionRequest
 
     private ExecutionListener executionListener;
 
-    private String threadCount;
+    private int degreeOfConcurrency = 1;
 
-    private boolean perCoreThreadCount;
+    private String builderId = "singlethreaded";
+
+    private Map<String, List<ToolchainModel>> toolchains;
 
     /**
      * Suppress SNAPSHOT updates.
@@ -143,6 +160,10 @@ public class DefaultMavenExecutionRequest
      */
     private boolean noSnapshotUpdates;
 
+    private boolean useLegacyLocalRepositoryManager = false;
+
+    private Map<String, Object> data;
+
     public DefaultMavenExecutionRequest()
     {
     }
@@ -165,8 +186,9 @@ public class DefaultMavenExecutionRequest
         copy.setUserSettingsFile( original.getUserSettingsFile() );
         copy.setGlobalSettingsFile( original.getGlobalSettingsFile() );
         copy.setUserToolchainsFile( original.getUserToolchainsFile() );
-        copy.setBaseDirectory( ( original.getBaseDirectory() != null )
-                               ? new File( original.getBaseDirectory() ) : null );
+        copy.setGlobalToolchainsFile( original.getGlobalToolchainsFile() );
+        copy.setBaseDirectory( ( original.getBaseDirectory() != null ) ? new File( original.getBaseDirectory() )
+                                                                       : null );
         copy.setGoals( original.getGoals() );
         copy.setRecursive( original.isRecursive() );
         copy.setPom( original.getPom() );
@@ -185,9 +207,12 @@ public class DefaultMavenExecutionRequest
         copy.setWorkspaceReader( original.getWorkspaceReader() );
         copy.setNoSnapshotUpdates( original.isNoSnapshotUpdates() );
         copy.setExecutionListener( original.getExecutionListener() );
+        copy.setUseLegacyLocalRepository( original.isUseLegacyLocalRepository() );
+        copy.setBuilderId( original.getBuilderId() );
         return copy;
     }
 
+    @Override
     public String getBaseDirectory()
     {
         if ( basedir == null )
@@ -198,25 +223,29 @@ public class DefaultMavenExecutionRequest
         return basedir.getAbsolutePath();
     }
 
+    @Override
     public ArtifactRepository getLocalRepository()
     {
         return localRepository;
     }
 
+    @Override
     public File getLocalRepositoryPath()
     {
         return localRepositoryPath;
     }
 
+    @Override
     public List<String> getGoals()
     {
         if ( goals == null )
         {
-            goals = new ArrayList<String>();
+            goals = new ArrayList<>();
         }
         return goals;
     }
 
+    @Override
     public Properties getSystemProperties()
     {
         if ( systemProperties == null )
@@ -227,6 +256,7 @@ public class DefaultMavenExecutionRequest
         return systemProperties;
     }
 
+    @Override
     public Properties getUserProperties()
     {
         if ( userProperties == null )
@@ -237,56 +267,76 @@ public class DefaultMavenExecutionRequest
         return userProperties;
     }
 
+    @Override
     public File getPom()
     {
         return pom;
     }
 
+    @Override
     public String getReactorFailureBehavior()
     {
         return reactorFailureBehavior;
     }
 
+    @Override
     public List<String> getSelectedProjects()
     {
         if ( selectedProjects == null )
         {
-            selectedProjects = new ArrayList<String>();
+            selectedProjects = new ArrayList<>();
         }
 
         return selectedProjects;
     }
 
+    @Override
+    public List<String> getExcludedProjects()
+    {
+        if ( excludedProjects == null )
+        {
+            excludedProjects = new ArrayList<>();
+        }
+
+        return excludedProjects;
+    }
+
+    @Override
     public String getResumeFrom()
     {
         return resumeFrom;
     }
 
+    @Override
     public String getMakeBehavior()
     {
         return makeBehavior;
     }
 
+    @Override
     public Date getStartTime()
     {
         return startTime;
     }
 
+    @Override
     public boolean isShowErrors()
     {
         return showErrors;
     }
 
+    @Override
     public boolean isInteractiveMode()
     {
         return interactiveMode;
     }
 
+    @Override
     public MavenExecutionRequest setActiveProfiles( List<String> activeProfiles )
     {
         if ( activeProfiles != null )
         {
-            this.activeProfiles = new ArrayList<String>( activeProfiles );
+            this.activeProfiles = new ArrayList<>( activeProfiles );
         }
         else
         {
@@ -296,11 +346,12 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest setInactiveProfiles( List<String> inactiveProfiles )
     {
         if ( inactiveProfiles != null )
         {
-            this.inactiveProfiles = new ArrayList<String>( inactiveProfiles );
+            this.inactiveProfiles = new ArrayList<>( inactiveProfiles );
         }
         else
         {
@@ -310,11 +361,12 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest setRemoteRepositories( List<ArtifactRepository> remoteRepositories )
     {
         if ( remoteRepositories != null )
         {
-            this.remoteRepositories = new ArrayList<ArtifactRepository>( remoteRepositories );
+            this.remoteRepositories = new ArrayList<>( remoteRepositories );
         }
         else
         {
@@ -324,11 +376,12 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest setPluginArtifactRepositories( List<ArtifactRepository> pluginArtifactRepositories )
     {
         if ( pluginArtifactRepositories != null )
         {
-            this.pluginArtifactRepositories = new ArrayList<ArtifactRepository>( pluginArtifactRepositories );
+            this.pluginArtifactRepositories = new ArrayList<>( pluginArtifactRepositories );
         }
         else
         {
@@ -343,54 +396,63 @@ public class DefaultMavenExecutionRequest
         this.projectBuildingRequest = projectBuildingConfiguration;
     }
 
+    @Override
     public List<String> getActiveProfiles()
     {
         if ( activeProfiles == null )
         {
-            activeProfiles = new ArrayList<String>();
+            activeProfiles = new ArrayList<>();
         }
         return activeProfiles;
     }
 
+    @Override
     public List<String> getInactiveProfiles()
     {
         if ( inactiveProfiles == null )
         {
-            inactiveProfiles = new ArrayList<String>();
+            inactiveProfiles = new ArrayList<>();
         }
         return inactiveProfiles;
     }
 
+    @Override
     public TransferListener getTransferListener()
     {
         return transferListener;
     }
 
+    @Override
     public int getLoggingLevel()
     {
         return loggingLevel;
     }
 
+    @Override
     public boolean isOffline()
     {
         return offline;
     }
 
+    @Override
     public boolean isUpdateSnapshots()
     {
         return updateSnapshots;
     }
 
+    @Override
     public boolean isNoSnapshotUpdates()
     {
         return noSnapshotUpdates;
     }
 
+    @Override
     public String getGlobalChecksumPolicy()
     {
         return globalChecksumPolicy;
     }
 
+    @Override
     public boolean isRecursive()
     {
         return recursive;
@@ -400,6 +462,7 @@ public class DefaultMavenExecutionRequest
     //
     // ----------------------------------------------------------------------
 
+    @Override
     public MavenExecutionRequest setBaseDirectory( File basedir )
     {
         this.basedir = basedir;
@@ -407,6 +470,7 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest setStartTime( Date startTime )
     {
         this.startTime = startTime;
@@ -414,6 +478,7 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest setShowErrors( boolean showErrors )
     {
         this.showErrors = showErrors;
@@ -421,11 +486,12 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest setGoals( List<String> goals )
     {
         if ( goals != null )
         {
-            this.goals = new ArrayList<String>( goals );
+            this.goals = new ArrayList<>( goals );
         }
         else
         {
@@ -435,6 +501,7 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest setLocalRepository( ArtifactRepository localRepository )
     {
         this.localRepository = localRepository;
@@ -447,6 +514,7 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest setLocalRepositoryPath( File localRepository )
     {
         localRepositoryPath = localRepository;
@@ -454,6 +522,7 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest setLocalRepositoryPath( String localRepository )
     {
         localRepositoryPath = ( localRepository != null ) ? new File( localRepository ) : null;
@@ -461,6 +530,7 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest setSystemProperties( Properties properties )
     {
         if ( properties != null )
@@ -476,6 +546,7 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest setUserProperties( Properties userProperties )
     {
         if ( userProperties != null )
@@ -491,6 +562,7 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest setReactorFailureBehavior( String failureBehavior )
     {
         reactorFailureBehavior = failureBehavior;
@@ -498,11 +570,12 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest setSelectedProjects( List<String> selectedProjects )
     {
         if ( selectedProjects != null )
         {
-            this.selectedProjects = new ArrayList<String>( selectedProjects );
+            this.selectedProjects = new ArrayList<>( selectedProjects );
         }
         else
         {
@@ -512,6 +585,22 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
+    public MavenExecutionRequest setExcludedProjects( List<String> excludedProjects )
+    {
+        if ( excludedProjects != null )
+        {
+            this.excludedProjects = new ArrayList<>( excludedProjects );
+        }
+        else
+        {
+            this.excludedProjects = null;
+        }
+
+        return this;
+    }
+
+    @Override
     public MavenExecutionRequest setResumeFrom( String project )
     {
         this.resumeFrom = project;
@@ -519,6 +608,7 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest setMakeBehavior( String makeBehavior )
     {
         this.makeBehavior = makeBehavior;
@@ -526,6 +616,7 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest addActiveProfile( String profile )
     {
         if ( !getActiveProfiles().contains( profile ) )
@@ -536,6 +627,7 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest addInactiveProfile( String profile )
     {
         if ( !getInactiveProfiles().contains( profile ) )
@@ -546,6 +638,7 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest addActiveProfiles( List<String> profiles )
     {
         for ( String profile : profiles )
@@ -556,6 +649,7 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest addInactiveProfiles( List<String> profiles )
     {
         for ( String profile : profiles )
@@ -579,6 +673,7 @@ public class DefaultMavenExecutionRequest
     }
 
     /** @deprecated use {@link #setPom(File)} */
+    @Deprecated
     public MavenExecutionRequest setPomFile( String pomFilename )
     {
         if ( pomFilename != null )
@@ -589,6 +684,7 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest setPom( File pom )
     {
         this.pom = pom;
@@ -596,6 +692,7 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest setInteractiveMode( boolean interactive )
     {
         interactiveMode = interactive;
@@ -603,6 +700,7 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest setTransferListener( TransferListener transferListener )
     {
         this.transferListener = transferListener;
@@ -610,6 +708,7 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest setLoggingLevel( int loggingLevel )
     {
         this.loggingLevel = loggingLevel;
@@ -617,6 +716,7 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest setOffline( boolean offline )
     {
         this.offline = offline;
@@ -624,6 +724,7 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest setUpdateSnapshots( boolean updateSnapshots )
     {
         this.updateSnapshots = updateSnapshots;
@@ -631,6 +732,7 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest setNoSnapshotUpdates( boolean noSnapshotUpdates )
     {
         this.noSnapshotUpdates = noSnapshotUpdates;
@@ -638,6 +740,7 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest setGlobalChecksumPolicy( String globalChecksumPolicy )
     {
         this.globalChecksumPolicy = globalChecksumPolicy;
@@ -649,20 +752,22 @@ public class DefaultMavenExecutionRequest
     // Settings equivalents
     // ----------------------------------------------------------------------------
 
+    @Override
     public List<Proxy> getProxies()
     {
         if ( proxies == null )
         {
-            proxies = new ArrayList<Proxy>();
+            proxies = new ArrayList<>();
         }
         return proxies;
     }
 
+    @Override
     public MavenExecutionRequest setProxies( List<Proxy> proxies )
     {
         if ( proxies != null )
         {
-            this.proxies = new ArrayList<Proxy>( proxies );
+            this.proxies = new ArrayList<>( proxies );
         }
         else
         {
@@ -672,12 +777,10 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest addProxy( Proxy proxy )
     {
-        if ( proxy == null )
-        {
-            throw new IllegalArgumentException( "proxy missing" );
-        }
+        Validate.notNull( proxy, "proxy cannot be null" );
 
         for ( Proxy p : getProxies() )
         {
@@ -692,20 +795,22 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public List<Server> getServers()
     {
         if ( servers == null )
         {
-            servers = new ArrayList<Server>();
+            servers = new ArrayList<>();
         }
         return servers;
     }
 
+    @Override
     public MavenExecutionRequest setServers( List<Server> servers )
     {
         if ( servers != null )
         {
-            this.servers = new ArrayList<Server>( servers );
+            this.servers = new ArrayList<>( servers );
         }
         else
         {
@@ -715,12 +820,10 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest addServer( Server server )
     {
-        if ( server == null )
-        {
-            throw new IllegalArgumentException( "server missing" );
-        }
+        Validate.notNull( server, "server cannot be null" );
 
         for ( Server p : getServers() )
         {
@@ -735,20 +838,22 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public List<Mirror> getMirrors()
     {
         if ( mirrors == null )
         {
-            mirrors = new ArrayList<Mirror>();
+            mirrors = new ArrayList<>();
         }
         return mirrors;
     }
 
+    @Override
     public MavenExecutionRequest setMirrors( List<Mirror> mirrors )
     {
         if ( mirrors != null )
         {
-            this.mirrors = new ArrayList<Mirror>( mirrors );
+            this.mirrors = new ArrayList<>( mirrors );
         }
         else
         {
@@ -758,12 +863,10 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest addMirror( Mirror mirror )
     {
-        if ( mirror == null )
-        {
-            throw new IllegalArgumentException( "mirror missing" );
-        }
+        Validate.notNull( mirror, "mirror cannot be null" );
 
         for ( Mirror p : getMirrors() )
         {
@@ -778,20 +881,22 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public List<Profile> getProfiles()
     {
         if ( profiles == null )
         {
-            profiles = new ArrayList<Profile>();
+            profiles = new ArrayList<>();
         }
         return profiles;
     }
 
+    @Override
     public MavenExecutionRequest setProfiles( List<Profile> profiles )
     {
         if ( profiles != null )
         {
-            this.profiles = new ArrayList<Profile>( profiles );
+            this.profiles = new ArrayList<>( profiles );
         }
         else
         {
@@ -801,21 +906,23 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public List<String> getPluginGroups()
     {
         if ( pluginGroups == null )
         {
-            pluginGroups = new ArrayList<String>();
+            pluginGroups = new ArrayList<>();
         }
 
         return pluginGroups;
     }
 
+    @Override
     public MavenExecutionRequest setPluginGroups( List<String> pluginGroups )
     {
         if ( pluginGroups != null )
         {
-            this.pluginGroups = new ArrayList<String>( pluginGroups );
+            this.pluginGroups = new ArrayList<>( pluginGroups );
         }
         else
         {
@@ -825,6 +932,7 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest addPluginGroup( String pluginGroup )
     {
         if ( !getPluginGroups().contains( pluginGroup ) )
@@ -835,6 +943,7 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest addPluginGroups( List<String> pluginGroups )
     {
         for ( String pluginGroup : pluginGroups )
@@ -845,6 +954,7 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public MavenExecutionRequest setRecursive( boolean recursive )
     {
         this.recursive = recursive;
@@ -855,11 +965,13 @@ public class DefaultMavenExecutionRequest
     // calculated from request attributes.
     private ProjectBuildingRequest projectBuildingRequest;
 
+    @Override
     public boolean isProjectPresent()
     {
         return isProjectPresent;
     }
 
+    @Override
     public MavenExecutionRequest setProjectPresent( boolean projectPresent )
     {
         isProjectPresent = projectPresent;
@@ -869,11 +981,13 @@ public class DefaultMavenExecutionRequest
 
     // Settings files
 
+    @Override
     public File getUserSettingsFile()
     {
         return userSettingsFile;
     }
 
+    @Override
     public MavenExecutionRequest setUserSettingsFile( File userSettingsFile )
     {
         this.userSettingsFile = userSettingsFile;
@@ -881,11 +995,13 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public File getGlobalSettingsFile()
     {
         return globalSettingsFile;
     }
 
+    @Override
     public MavenExecutionRequest setGlobalSettingsFile( File globalSettingsFile )
     {
         this.globalSettingsFile = globalSettingsFile;
@@ -893,11 +1009,13 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public File getUserToolchainsFile()
     {
         return userToolchainsFile;
     }
 
+    @Override
     public MavenExecutionRequest setUserToolchainsFile( File userToolchainsFile )
     {
         this.userToolchainsFile = userToolchainsFile;
@@ -905,6 +1023,20 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
+    public File getGlobalToolchainsFile()
+    {
+        return globalToolchainsFile;
+    }
+
+    @Override
+    public MavenExecutionRequest setGlobalToolchainsFile( File globalToolchainsFile )
+    {
+        this.globalToolchainsFile = globalToolchainsFile;
+        return this;
+    }
+
+    @Override
     public MavenExecutionRequest addRemoteRepository( ArtifactRepository repository )
     {
         for ( ArtifactRepository repo : getRemoteRepositories() )
@@ -920,15 +1052,17 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public List<ArtifactRepository> getRemoteRepositories()
     {
         if ( remoteRepositories == null )
         {
-            remoteRepositories = new ArrayList<ArtifactRepository>();
+            remoteRepositories = new ArrayList<>();
         }
         return remoteRepositories;
     }
 
+    @Override
     public MavenExecutionRequest addPluginArtifactRepository( ArtifactRepository repository )
     {
         for ( ArtifactRepository repo : getPluginArtifactRepositories() )
@@ -944,16 +1078,18 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public List<ArtifactRepository> getPluginArtifactRepositories()
     {
         if ( pluginArtifactRepositories == null )
         {
-            pluginArtifactRepositories = new ArrayList<ArtifactRepository>();
+            pluginArtifactRepositories = new ArrayList<>();
         }
         return pluginArtifactRepositories;
     }
 
-    //TODO: this does not belong here.
+    // TODO: this does not belong here.
+    @Override
     public ProjectBuildingRequest getProjectBuildingRequest()
     {
         if ( projectBuildingRequest == null )
@@ -974,12 +1110,10 @@ public class DefaultMavenExecutionRequest
         return projectBuildingRequest;
     }
 
+    @Override
     public MavenExecutionRequest addProfile( Profile profile )
     {
-        if ( profile == null )
-        {
-            throw new IllegalArgumentException( "profile missing" );
-        }
+        Validate.notNull( profile, "profile cannot be null" );
 
         for ( Profile p : getProfiles() )
         {
@@ -994,11 +1128,13 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public RepositoryCache getRepositoryCache()
     {
         return repositoryCache;
     }
 
+    @Override
     public MavenExecutionRequest setRepositoryCache( RepositoryCache repositoryCache )
     {
         this.repositoryCache = repositoryCache;
@@ -1006,11 +1142,13 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
+    @Override
     public ExecutionListener getExecutionListener()
     {
         return executionListener;
     }
 
+    @Override
     public MavenExecutionRequest setExecutionListener( ExecutionListener executionListener )
     {
         this.executionListener = executionListener;
@@ -1018,62 +1156,133 @@ public class DefaultMavenExecutionRequest
         return this;
     }
 
-    public String getThreadCount()
+    @Override
+    public void setDegreeOfConcurrency( final int degreeOfConcurrency )
     {
-        return threadCount;
+        this.degreeOfConcurrency = degreeOfConcurrency;
     }
 
-    public void setThreadCount( String threadCount )
+    @Override
+    public int getDegreeOfConcurrency()
     {
-        this.threadCount = threadCount;
-    }
-
-    public boolean isThreadConfigurationPresent()
-    {
-        return getThreadCount() != null;
-    }
-
-    public boolean isPerCoreThreadCount()
-    {
-        return perCoreThreadCount;
-    }
-
-    public void setPerCoreThreadCount( boolean perCoreThreadCount )
-    {
-        this.perCoreThreadCount = perCoreThreadCount;
+        return degreeOfConcurrency;
     }
 
+    @Override
     public WorkspaceReader getWorkspaceReader()
     {
         return workspaceReader;
     }
 
+    @Override
     public MavenExecutionRequest setWorkspaceReader( WorkspaceReader workspaceReader )
     {
         this.workspaceReader = workspaceReader;
         return this;
     }
 
+    @Override
     public boolean isCacheTransferError()
     {
         return cacheTransferError;
     }
 
+    @Override
     public MavenExecutionRequest setCacheTransferError( boolean cacheTransferError )
     {
         this.cacheTransferError = cacheTransferError;
         return this;
     }
 
+    @Override
     public boolean isCacheNotFound()
     {
         return cacheNotFound;
     }
 
+    @Override
     public MavenExecutionRequest setCacheNotFound( boolean cacheNotFound )
     {
         this.cacheNotFound = cacheNotFound;
         return this;
     }
 
+    @Override
+    public boolean isUseLegacyLocalRepository()
+    {
+        return this.useLegacyLocalRepositoryManager;
+    }
+
+    @Override
+    public MavenExecutionRequest setUseLegacyLocalRepository( boolean useLegacyLocalRepositoryManager )
+    {
+        this.useLegacyLocalRepositoryManager = useLegacyLocalRepositoryManager;
+        return this;
+    }
+
+    @Override
+    public MavenExecutionRequest setBuilderId( String builderId )
+    {
+        this.builderId = builderId;
+        return this;
+    }
+
+    @Override
+    public String getBuilderId()
+    {
+        return builderId;
+    }
+
+    @Override
+    public Map<String, List<ToolchainModel>> getToolchains()
+    {
+        if ( toolchains == null )
+        {
+            toolchains = new HashMap<>();
+        }
+        return toolchains;
+    }
+
+    @Override
+    public MavenExecutionRequest setToolchains( Map<String, List<ToolchainModel>> toolchains )
+    {
+        this.toolchains = toolchains;
+        return this;
+    }
+
+    @Override
+    public void setMultiModuleProjectDirectory( File directory )
+    {
+        this.multiModuleProjectDirectory = directory;
+    }
+
+    @Override
+    public File getMultiModuleProjectDirectory()
+    {
+        return multiModuleProjectDirectory;
+    }
+
+    @Override
+    public MavenExecutionRequest setEventSpyDispatcher( EventSpyDispatcher eventSpyDispatcher )
+    {
+        this.eventSpyDispatcher = eventSpyDispatcher;
+        return this;
+    }
+
+    @Override
+    public EventSpyDispatcher getEventSpyDispatcher()
+    {
+        return eventSpyDispatcher;
+    }
+
+    @Override
+    public Map<String, Object> getData()
+    {
+        if ( data == null )
+        {
+            data = Maps.newHashMap();
+        }
+
+        return data;
+    }
 }
