@@ -25,6 +25,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
 
+import org.apache.commons.lang3.Validate;
 import org.apache.maven.artifact.Artifact;
 import org.apache.maven.model.Plugin;
 import org.apache.maven.project.MavenProject;
@@ -66,7 +67,7 @@ public class DefaultPluginArtifactsCache
             this.plugin = plugin.clone();
             workspace = CacheUtils.getWorkspace( session );
             this.localRepo = session.getLocalRepository();
-            this.repositories = new ArrayList<RemoteRepository>( repositories.size() );
+            this.repositories = new ArrayList<>( repositories.size() );
             for ( RemoteRepository repository : repositories )
             {
                 if ( repository.isRepositoryManager() )
@@ -133,7 +134,7 @@ public class DefaultPluginArtifactsCache
 
     }
 
-    protected final Map<Key, CacheRecord> cache = new ConcurrentHashMap<Key, CacheRecord>();
+    protected final Map<Key, CacheRecord> cache = new ConcurrentHashMap<>();
 
     public Key createKey( Plugin plugin, DependencyFilter extensionFilter, List<RemoteRepository> repositories,
                           RepositorySystemSession session )
@@ -156,15 +157,12 @@ public class DefaultPluginArtifactsCache
 
     public CacheRecord put( Key key, List<Artifact> pluginArtifacts )
     {
-        if ( pluginArtifacts == null )
-        {
-            throw new NullPointerException();
-        }
+        Validate.notNull( pluginArtifacts, "pluginArtifacts cannot be null" );
 
         assertUniqueKey( key );
 
         CacheRecord record =
-            new CacheRecord( Collections.unmodifiableList( new ArrayList<Artifact>( pluginArtifacts ) ) );
+            new CacheRecord( Collections.unmodifiableList( new ArrayList<>( pluginArtifacts ) ) );
 
         cache.put( key, record );
 
@@ -181,10 +179,7 @@ public class DefaultPluginArtifactsCache
 
     public CacheRecord put( Key key, PluginResolutionException exception )
     {
-        if ( exception == null )
-        {
-            throw new NullPointerException();
-        }
+        Validate.notNull( exception, "exception cannot be null" );
 
         assertUniqueKey( key );
 
