@@ -33,7 +33,42 @@ import org.codehaus.plexus.logging.Logger;
 import org.codehaus.plexus.util.introspection.ReflectionValueExtractor;
 
 /**
+ * Evaluator for plugin parameters expressions. Content surrounded by <code>${</code> and <code>}</code> is evaluated.
+ * Recognized values are:<table border="1">
+ * <tr><th>expression</th>                     <th></th>               <th>evaluation result</th></tr>
+ * <tr><td><code>session</code></td>           <td></td>               <td>the actual {@link MavenSession}</td></tr>
+ * <tr><td><code>session.*</code></td>         <td>(since Maven 3)</td><td></td></tr>
+ * <tr><td><code>localRepository</code></td>   <td></td>
+ *                                             <td>{@link MavenSession#getLocalRepository()}</td></tr>
+ * <tr><td><code>reactorProjects</code></td>   <td></td>               <td>{@link MavenSession#getProjects()}</td></tr>
+ * <tr><td><code>repositorySystemSession</code></td><td> (since Maven 3)</td>
+ *                                             <td>{@link MavenSession#getRepositorySession()}</td></tr>
+ * <tr><td><code>project</code></td>           <td></td>
+ *                                             <td>{@link MavenSession#getCurrentProject()}</td></tr>
+ * <tr><td><code>project.*</code></td>         <td></td>               <td></td></tr>
+ * <tr><td><code>pom.*</code></td>             <td>(since Maven 3)</td><td>same as <code>project.*</code></td></tr>
+ * <tr><td><code>executedProject</code></td>   <td></td>
+ *                                             <td>{@link MavenProject#getExecutionProject()}</td></tr>
+ * <tr><td><code>settings</code></td>          <td></td>               <td>{@link MavenSession#getSettings()}</td></tr>
+ * <tr><td><code>settings.*</code></td>        <td></td>               <td></td></tr>
+ * <tr><td><code>basedir</code></td>           <td></td>
+ *                                             <td>{@link MavenSession#getExecutionRootDirectory()} or 
+ *                                                 <code>System.getProperty( "user.dir" )</code> if null</td></tr>
+ * <tr><td><code>mojoExecution</code></td>     <td></td>               <td>the actual {@link MojoExecution}</td></tr>
+ * <tr><td><code>mojo</code></td>              <td>(since Maven 3)</td><td>same as <code>mojoExecution</code></td></tr>
+ * <tr><td><code>mojo.*</code></td>            <td>(since Maven 3)</td><td></td></tr>
+ * <tr><td><code>plugin</code></td>            <td>(since Maven 3)</td>
+ *                             <td>{@link MojoExecution#getMojoDescriptor()}.{@link MojoDescriptor#getPluginDescriptor()
+ *                                 getPluginDescriptor()}</td></tr>
+ * <tr><td><code>plugin.*</code></td>          <td></td>               <td></td></tr>
+ * <tr><td><code>*</code></td>                 <td></td>               <td>system properties</td></tr>
+ * <tr><td><code>*</code></td>                 <td></td>               <td>project properties</td></tr>
+ * </table>
+ * <i>Notice:</i> <code>reports</code> was supported in Maven 2.x but was removed in Maven 3
+ *
  * @author Jason van Zyl
+ * @see MavenSession
+ * @see MojoExecution
  */
 public class PluginParameterExpressionEvaluator
     implements TypeAwareExpressionEvaluator
@@ -65,9 +100,16 @@ public class PluginParameterExpressionEvaluator
     {
         this.session = session;
         this.mojoExecution = mojoExecution;
-        this.properties = session.getExecutionProperties();
+        this.properties = new Properties();
         this.project = session.getCurrentProject();
 
+        //
+        // Maven4: We may want to evaluate how this is used but we add these separate as the 
+        // getExecutionProperties is deprecated in MavenSession.
+        //
+        this.properties.putAll( session.getUserProperties() );
+        this.properties.putAll( session.getSystemProperties() );
+        
         String basedir = null;
 
         if ( project != null )
@@ -81,7 +123,7 @@ public class PluginParameterExpressionEvaluator
             }
         }
 
-        if ( ( basedir == null ) && ( session != null ) )
+        if ( basedir == null )
         {
             basedir = session.getExecutionRootDirectory();
         }
@@ -94,12 +136,14 @@ public class PluginParameterExpressionEvaluator
         this.basedir = basedir;
     }
 
+    @Override
     public Object evaluate( String expr )
         throws ExpressionEvaluationException
     {
         return evaluate( expr, null );
     }
 
+    @Override
     public Object evaluate( String expr, Class<?> type )
         throws ExpressionEvaluationException
     {
@@ -145,7 +189,7 @@ public class PluginParameterExpressionEvaluator
             }
 
             // Was not an expression
-            if ( expression.indexOf( "$$" ) > -1 )
+            if ( expression.contains( "$$" ) )
             {
                 return expression.replaceAll( "\\$\\$", "\\$" );
             }
@@ -349,7 +393,7 @@ public class PluginParameterExpressionEvaluator
         {
             // The CLI should win for defining properties
 
-            if ( ( value == null ) && ( properties != null ) )
+            if ( properties != null )
             {
                 // We will attempt to get nab a system property as a way to specify a
                 // parameter to a plugins. My particular case here is allowing the surefire
@@ -410,6 +454,7 @@ public class PluginParameterExpressionEvaluator
         return expr;
     }
 
+    @Override
     public File alignToBaseDirectory( File file )
     {
         // TODO: Copied from the DefaultInterpolator. We likely want to resurrect the PathTranslator or at least a
