@@ -20,20 +20,10 @@ package org.apache.maven.model.building;
  */
 
 
-import static org.apache.maven.model.building.Result.error;
-import static org.apache.maven.model.building.Result.newResult;
-
-import java.io.File;
-import java.io.IOException;
-import java.util.ArrayList;
-import java.util.Collection;
-import java.util.HashMap;
-import java.util.Iterator;
-import java.util.LinkedHashSet;
-import java.util.List;
-import java.util.Map;
-import java.util.Properties;
-
+import org.apache.commons.lang3.Validate;
+import org.apache.maven.artifact.versioning.DefaultArtifactVersion;
+import org.apache.maven.artifact.versioning.InvalidVersionSpecificationException;
+import org.apache.maven.artifact.versioning.VersionRange;
 import org.apache.maven.model.Activation;
 import org.apache.maven.model.Build;
 import org.apache.maven.model.Dependency;
@@ -73,6 +63,20 @@ import org.apache.maven.model.validation.ModelValidator;
 import org.codehaus.plexus.component.annotations.Component;
 import org.codehaus.plexus.component.annotations.Requirement;
 
+import java.io.File;
+import java.io.IOException;
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.HashMap;
+import java.util.Iterator;
+import java.util.LinkedHashSet;
+import java.util.List;
+import java.util.Map;
+import java.util.Properties;
+
+import static org.apache.maven.model.building.Result.error;
+import static org.apache.maven.model.building.Result.newResult;
+
 /**
  * @author Benjamin Bentmann
  */
@@ -274,8 +278,8 @@ public class DefaultModelBuilder
         ModelData resultData = new ModelData( request.getModelSource(), inputModel );
         ModelData superData = new ModelData( null, getSuperModel() );
 
-        Collection<String> parentIds = new LinkedHashSet<String>();
-        List<ModelData> lineage = new ArrayList<ModelData>();
+        Collection<String> parentIds = new LinkedHashSet<>();
+        List<ModelData> lineage = new ArrayList<>();
 
         for ( ModelData currentData = resultData; currentData != null; )
         {
@@ -483,7 +487,7 @@ public class DefaultModelBuilder
     {
         final ModelBuildingRequest request = new DefaultModelBuildingRequest().setValidationLevel( validationLevel )
             .setLocationTracking( locationTracking );
-        final DefaultModelProblemCollector collector = 
+        final DefaultModelProblemCollector collector =
             new DefaultModelProblemCollector( new DefaultModelBuildingResult() );
         try
         {
@@ -509,7 +513,7 @@ public class DefaultModelBuilder
             }
             else
             {
-                throw new IllegalArgumentException( "neither model source nor input file are specified" );
+                throw new NullPointerException( "neither pomFile nor modelSource can be null" );
             }
         }
 
@@ -519,7 +523,7 @@ public class DefaultModelBuilder
             boolean strict = request.getValidationLevel() >= ModelBuildingRequest.VALIDATION_LEVEL_MAVEN_2_0;
             InputSource source = request.isLocationTracking() ? new InputSource() : null;
 
-            Map<String, Object> options = new HashMap<String, Object>();
+            Map<String, Object> options = new HashMap<>();
             options.put( ModelProcessor.IS_STRICT, strict );
             options.put( ModelProcessor.INPUT_SOURCE, source );
             options.put( ModelProcessor.SOURCE, modelSource );
@@ -660,9 +664,9 @@ public class DefaultModelBuilder
             return;
         }
 
-        Map<String, Plugin> plugins = new HashMap<String, Plugin>();
-        Map<String, String> versions = new HashMap<String, String>();
-        Map<String, String> managedVersions = new HashMap<String, String>();
+        Map<String, Plugin> plugins = new HashMap<>();
+        Map<String, String> versions = new HashMap<>();
+        Map<String, String> managedVersions = new HashMap<>();
 
         for ( int i = lineage.size() - 1; i >= 0; i-- )
         {
@@ -720,7 +724,7 @@ public class DefaultModelBuilder
 
     private Map<String, Activation> getProfileActivations( Model model, boolean clone )
     {
-        Map<String, Activation> activations = new HashMap<String, Activation>();
+        Map<String, Activation> activations = new HashMap<>();
         for ( Profile profile : model.getProfiles() )
         {
             Activation activation = profile.getActivation();
@@ -919,6 +923,28 @@ public class DefaultModelBuilder
                 .setMessage( buffer.toString() ).setLocation( parent.getLocation( "" ) ) );
             return null;
         }
+        if ( version != null && parent.getVersion() != null && !version.equals( parent.getVersion() ) )
+        {
+            try
+            {
+                VersionRange parentRange = VersionRange.createFromVersionSpec( parent.getVersion() );
+                if ( !parentRange.hasRestrictions() )
+                {
+                    // the parent version is not a range, we have version skew, drop back to resolution from repo
+                    return null;
+                }
+                if ( !parentRange.containsVersion( new DefaultArtifactVersion( version ) ) )
+                {
+                    // version skew drop back to resolution from the repository
+                    return null;
+                }
+            }
+            catch ( InvalidVersionSpecificationException e )
+            {
+                // invalid version range, so drop back to resolution from the repository
+                return null;
+            }
+        }
 
         //
         // Here we just need to know that a version is fine to use but this validation we can do in our workspace
@@ -965,12 +991,8 @@ public class DefaultModelBuilder
 
         ModelResolver modelResolver = request.getModelResolver();
 
-        if ( modelResolver == null )
-        {
-            throw new IllegalArgumentException( "no model resolver provided, cannot resolve parent POM "
-                + ModelProblemUtils.toId( groupId, artifactId, version ) + " for POM "
-                + ModelProblemUtils.toSourceHint( childModel ) );
-        }
+        Validate.notNull( modelResolver, "request.modelResolver cannot be null (parent POM %s and POM %s)",
+            ModelProblemUtils.toId( groupId, artifactId, version ), ModelProblemUtils.toSourceHint( childModel ) );
 
         ModelSource modelSource;
         try
@@ -1032,7 +1054,8 @@ public class DefaultModelBuilder
             }
             else
             {
-                if ( childModel.getVersion().indexOf( "${" ) > -1 )
+                if ( childModel.getVersion()
+                               .contains( "${" ) )
                 {
                     problems.add( new ModelProblemCollectorRequest( Severity.FATAL, Version.V31 )
                         .setMessage( "Version must be a constant" )
@@ -1138,9 +1161,11 @@ public class DefaultModelBuilder
             {
                 if ( workspaceResolver == null && modelResolver == null )
                 {
-                    throw new IllegalArgumentException( "no model resolver provided, cannot resolve import POM "
-                        + ModelProblemUtils.toId( groupId, artifactId, version ) + " for POM "
-                        + ModelProblemUtils.toSourceHint( model ) );
+                    throw new NullPointerException( String.format(
+                        "request.workspaceModelResolver and request.modelResolver cannot be null"
+                        + " (parent POM %s and POM %s)",
+                        ModelProblemUtils.toId( groupId, artifactId, version ),
+                        ModelProblemUtils.toSourceHint( model ) ) );
                 }
 
                 Model importModel = null;
@@ -1223,7 +1248,7 @@ public class DefaultModelBuilder
 
             if ( importMngts == null )
             {
-                importMngts = new ArrayList<DependencyManagement>();
+                importMngts = new ArrayList<>();
             }
 
             importMngts.add( importMngt );
