@@ -28,17 +28,13 @@ import java.util.Set;
 
 import org.apache.maven.model.BuildBase;
 import org.apache.maven.model.CiManagement;
-import org.apache.maven.model.Contributor;
 import org.apache.maven.model.Dependency;
 import org.apache.maven.model.DeploymentRepository;
-import org.apache.maven.model.Developer;
 import org.apache.maven.model.DistributionManagement;
 import org.apache.maven.model.Exclusion;
 import org.apache.maven.model.Extension;
 import org.apache.maven.model.InputLocation;
 import org.apache.maven.model.IssueManagement;
-import org.apache.maven.model.License;
-import org.apache.maven.model.MailingList;
 import org.apache.maven.model.Model;
 import org.apache.maven.model.ModelBase;
 import org.apache.maven.model.Organization;
@@ -52,7 +48,8 @@ import org.apache.maven.model.Scm;
 import org.apache.maven.model.Site;
 
 /**
- * The domain-specific model merger for the Maven POM.
+ * The domain-specific model merger for the Maven POM, overriding generic code from parent class when necessary with
+ * more adapted algorithms.
  *
  * @author Benjamin Bentmann
  */
@@ -68,7 +65,7 @@ public class MavenModelMerger
     /**
      * The context key for the artifact id of the target model.
      */
-    private static final String ARTIFACT_ID = "artifact-id";
+    public static final String ARTIFACT_ID = "artifact-id";
 
     @Override
     protected void mergeModel( Model target, Model source, boolean sourceDominant, Map<Object, Object> context )
@@ -105,7 +102,7 @@ public class MavenModelMerger
             }
             else if ( target.getUrl() == null )
             {
-                target.setUrl( appendPath( src, context ) );
+                target.setUrl( extrapolateChildUrl( src, context ) );
                 target.setLocation( "url", source.getLocation( "url" ) );
             }
         }
@@ -203,7 +200,7 @@ public class MavenModelMerger
     {
         if ( target.getLicenses().isEmpty() )
         {
-            target.setLicenses( new ArrayList<License>( source.getLicenses() ) );
+            target.setLicenses( new ArrayList<>( source.getLicenses() ) );
         }
     }
 
@@ -213,7 +210,7 @@ public class MavenModelMerger
     {
         if ( target.getDevelopers().isEmpty() )
         {
-            target.setDevelopers( new ArrayList<Developer>( source.getDevelopers() ) );
+            target.setDevelopers( new ArrayList<>( source.getDevelopers() ) );
         }
     }
 
@@ -223,7 +220,7 @@ public class MavenModelMerger
     {
         if ( target.getContributors().isEmpty() )
         {
-            target.setContributors( new ArrayList<Contributor>( source.getContributors() ) );
+            target.setContributors( new ArrayList<>( source.getContributors() ) );
         }
     }
 
@@ -233,7 +230,7 @@ public class MavenModelMerger
     {
         if ( target.getMailingLists().isEmpty() )
         {
-            target.setMailingLists( new ArrayList<MailingList>( source.getMailingLists() ) );
+            target.setMailingLists( new ArrayList<>( source.getMailingLists() ) );
         }
     }
 
@@ -244,14 +241,14 @@ public class MavenModelMerger
         List<String> src = source.getModules();
         if ( !src.isEmpty() && sourceDominant )
         {
-            List<Integer> indices = new ArrayList<Integer>();
+            List<Integer> indices = new ArrayList<>();
             List<String> tgt = target.getModules();
-            Set<String> excludes = new LinkedHashSet<String>( tgt );
-            List<String> merged = new ArrayList<String>( tgt.size() + src.size() );
+            Set<String> excludes = new LinkedHashSet<>( tgt );
+            List<String> merged = new ArrayList<>( tgt.size() + src.size() );
             merged.addAll( tgt );
             for ( int i = 0, n = tgt.size(); i < n; i++ )
             {
-                indices.add( Integer.valueOf( i ) );
+                indices.add( i );
             }
             for ( int i = 0, n = src.size(); i < n; i++ )
             {
@@ -259,7 +256,7 @@ public class MavenModelMerger
                 if ( !excludes.contains( s ) )
                 {
                     merged.add( s );
-                    indices.add( Integer.valueOf( ~i ) );
+                    indices.add( ~i );
                 }
             }
             target.setModules( merged );
@@ -280,7 +277,7 @@ public class MavenModelMerger
         if ( !src.isEmpty() )
         {
             List<Repository> tgt = target.getRepositories();
-            Map<Object, Repository> merged = new LinkedHashMap<Object, Repository>( ( src.size() + tgt.size() ) * 2 );
+            Map<Object, Repository> merged = new LinkedHashMap<>( ( src.size() + tgt.size() ) * 2 );
 
             List<Repository> dominant, recessive;
             if ( sourceDominant )
@@ -309,7 +306,48 @@ public class MavenModelMerger
                 }
             }
 
-            target.setRepositories( new ArrayList<Repository>( merged.values() ) );
+            target.setRepositories( new ArrayList<>( merged.values() ) );
+        }
+    }
+
+    @Override
+    protected void mergeModelBase_PluginRepositories( ModelBase target, ModelBase source, boolean sourceDominant,
+                                                      Map<Object, Object> context )
+    {
+        List<Repository> src = source.getPluginRepositories();
+        if ( !src.isEmpty() )
+        {
+            List<Repository> tgt = target.getPluginRepositories();
+            Map<Object, Repository> merged = new LinkedHashMap<>( ( src.size() + tgt.size() ) * 2 );
+
+            List<Repository> dominant, recessive;
+            if ( sourceDominant )
+            {
+                dominant = src;
+                recessive = tgt;
+            }
+            else
+            {
+                dominant = tgt;
+                recessive = src;
+            }
+
+            for ( Repository element : dominant )
+            {
+                Object key = getRepositoryKey( element );
+                merged.put( key, element );
+            }
+
+            for ( Repository element : recessive )
+            {
+                Object key = getRepositoryKey( element );
+                if ( !merged.containsKey( key ) )
+                {
+                    merged.put( key, element );
+                }
+            }
+
+            target.setPluginRepositories( new ArrayList<>( merged.values() ) );
         }
     }
 
@@ -324,8 +362,8 @@ public class MavenModelMerger
         if ( !src.isEmpty() )
         {
             List<String> tgt = target.getFilters();
-            Set<String> excludes = new LinkedHashSet<String>( tgt );
-            List<String> merged = new ArrayList<String>( tgt.size() + src.size() );
+            Set<String> excludes = new LinkedHashSet<>( tgt );
+            List<String> merged = new ArrayList<>( tgt.size() + src.size() );
             merged.addAll( tgt );
             for ( String s : src )
             {
@@ -428,7 +466,7 @@ public class MavenModelMerger
             }
             else if ( target.getUrl() == null )
             {
-                target.setUrl( appendPath( src, context ) );
+                target.setUrl( extrapolateChildUrl( src, context ) );
                 target.setLocation( "url", source.getLocation( "url" ) );
             }
         }
@@ -447,7 +485,7 @@ public class MavenModelMerger
             }
             else if ( target.getUrl() == null )
             {
-                target.setUrl( appendPath( src, context ) );
+                target.setUrl( extrapolateChildUrl( src, context ) );
                 target.setLocation( "url", source.getLocation( "url" ) );
             }
         }
@@ -466,7 +504,7 @@ public class MavenModelMerger
             }
             else if ( target.getConnection() == null )
             {
-                target.setConnection( appendPath( src, context ) );
+                target.setConnection( extrapolateChildUrl( src, context ) );
                 target.setLocation( "connection", source.getLocation( "connection" ) );
             }
         }
@@ -486,7 +524,7 @@ public class MavenModelMerger
             }
             else if ( target.getDeveloperConnection() == null )
             {
-                target.setDeveloperConnection( appendPath( src, context ) );
+                target.setDeveloperConnection( extrapolateChildUrl( src, context ) );
                 target.setLocation( "developerConnection", source.getLocation( "developerConnection" ) );
             }
         }
@@ -501,7 +539,7 @@ public class MavenModelMerger
         {
             List<PluginExecution> tgt = target.getExecutions();
             Map<Object, PluginExecution> merged =
-                new LinkedHashMap<Object, PluginExecution>( ( src.size() + tgt.size() ) * 2 );
+                new LinkedHashMap<>( ( src.size() + tgt.size() ) * 2 );
 
             for ( PluginExecution element : src )
             {
@@ -524,7 +562,7 @@ public class MavenModelMerger
                 merged.put( key, element );
             }
 
-            target.setExecutions( new ArrayList<PluginExecution>( merged.values() ) );
+            target.setExecutions( new ArrayList<>( merged.values() ) );
         }
     }
 
@@ -536,8 +574,8 @@ public class MavenModelMerger
         if ( !src.isEmpty() )
         {
             List<String> tgt = target.getGoals();
-            Set<String> excludes = new LinkedHashSet<String>( tgt );
-            List<String> merged = new ArrayList<String>( tgt.size() + src.size() );
+            Set<String> excludes = new LinkedHashSet<>( tgt );
+            List<String> merged = new ArrayList<>( tgt.size() + src.size() );
             merged.addAll( tgt );
             for ( String s : src )
             {
@@ -558,14 +596,14 @@ public class MavenModelMerger
         if ( !src.isEmpty() )
         {
             List<ReportSet> tgt = target.getReportSets();
-            Map<Object, ReportSet> merged = new LinkedHashMap<Object, ReportSet>( ( src.size() + tgt.size() ) * 2 );
+            Map<Object, ReportSet> merged = new LinkedHashMap<>( ( src.size() + tgt.size() ) * 2 );
 
-            for ( ReportSet element : src )
+            for ( ReportSet rset : src )
             {
-                if ( sourceDominant || ( element.getInherited() != null ? element.isInherited() : source.isInherited() ) )
+                if ( sourceDominant || ( rset.getInherited() != null ? rset.isInherited() : source.isInherited() ) )
                 {
-                    Object key = getReportSetKey( element );
-                    merged.put( key, element );
+                    Object key = getReportSetKey( rset );
+                    merged.put( key, rset );
                 }
             }
 
@@ -580,7 +618,7 @@ public class MavenModelMerger
                 merged.put( key, element );
             }
 
-            target.setReportSets( new ArrayList<ReportSet>( merged.values() ) );
+            target.setReportSets( new ArrayList<>( merged.values() ) );
         }
     }
 
@@ -591,97 +629,50 @@ public class MavenModelMerger
     }
 
     @Override
-    protected Object getPluginKey( Plugin object )
+    protected Object getPluginKey( Plugin plugin )
     {
-        return object.getKey();
+        return plugin.getKey();
     }
 
     @Override
-    protected Object getPluginExecutionKey( PluginExecution object )
+    protected Object getPluginExecutionKey( PluginExecution pluginExecution )
     {
-        return object.getId();
+        return pluginExecution.getId();
     }
 
     @Override
-    protected Object getReportPluginKey( ReportPlugin object )
+    protected Object getReportPluginKey( ReportPlugin reportPlugin )
     {
-        return object.getKey();
+        return reportPlugin.getKey();
     }
 
     @Override
-    protected Object getReportSetKey( ReportSet object )
+    protected Object getReportSetKey( ReportSet reportSet )
     {
-        return object.getId();
+        return reportSet.getId();
     }
 
     @Override
-    protected Object getRepositoryBaseKey( RepositoryBase object )
+    protected Object getRepositoryBaseKey( RepositoryBase repositoryBase )
     {
-        return object.getId();
+        return repositoryBase.getId();
     }
 
     @Override
-    protected Object getExtensionKey( Extension object )
+    protected Object getExtensionKey( Extension extension )
     {
-        return object.getGroupId() + ':' + object.getArtifactId();
+        return extension.getGroupId() + ':' + extension.getArtifactId();
     }
 
     @Override
-    protected Object getExclusionKey( Exclusion object )
+    protected Object getExclusionKey( Exclusion exclusion )
     {
-        return object.getGroupId() + ':' + object.getArtifactId();
+        return exclusion.getGroupId() + ':' + exclusion.getArtifactId();
     }
 
-    private String appendPath( String parentPath, Map<Object, Object> context )
+    protected String extrapolateChildUrl( String parentUrl, Map<Object, Object> context )
     {
-        Object artifactId = context.get( ARTIFACT_ID );
-        Object childPathAdjustment = context.get( CHILD_PATH_ADJUSTMENT );
-
-        if ( artifactId != null && childPathAdjustment != null )
-        {
-            return appendPath( parentPath, artifactId.toString(), childPathAdjustment.toString() );
-        }
-        else
-        {
-            return parentPath;
-        }
-    }
-
-    private String appendPath( String parentPath, String childPath, String pathAdjustment )
-    {
-        String path = parentPath;
-        path = concatPath( path, pathAdjustment );
-        path = concatPath( path, childPath );
-        return path;
-    }
-
-    private String concatPath( String base, String path )
-    {
-        String result = base;
-
-        if ( path != null && path.length() > 0 )
-        {
-            if ( ( result.endsWith( "/" ) && !path.startsWith( "/" ) )
-                || ( !result.endsWith( "/" ) && path.startsWith( "/" ) ) )
-            {
-                result += path;
-            }
-            else if ( result.endsWith( "/" ) && path.startsWith( "/" ) )
-            {
-                result += path.substring( 1 );
-            }
-            else
-            {
-                result += '/';
-                result += path;
-            }
-            if ( base.endsWith( "/" ) && !result.endsWith( "/" ) )
-            {
-                result += '/';
-            }
-        }
-
-        return result;
+        return parentUrl;
     }
 
 }
