@@ -63,28 +63,42 @@ public class MojoDescriptor
     /** By default, the execution strategy is "once-per-session" */
     private String executionStrategy = SINGLE_PASS_EXEC_STRATEGY;
 
-    /** The goal name of the Mojo */
+    /**
+     * The goal name for the Mojo, that users will reference from the command line to execute the Mojo directly, or
+     * inside a POM in order to provide Mojo-specific configuration.
+     */
     private String goal;
 
-    /** Reference the binded phase name of the Mojo */
+    /**
+     * Defines a default phase to bind a mojo execution to if the user does not explicitly set a phase in the POM.
+     * <i>Note:</i> This will not automagically make a mojo run when the plugin declaration is added to the POM. It
+     * merely enables the user to omit the <code>&lt;phase&gt;</code> element from the surrounding
+     * <code>&lt;execution&gt;</code> element.
+     */
     private String phase;
 
     /** Specify the version when the Mojo was added to the API. Similar to Javadoc since. */
     private String since;
 
-    /** Reference the invocation phase of the Mojo */
+    /** Reference the invocation phase of the Mojo. */
     private String executePhase;
 
-    /** Reference the invocation goal of the Mojo */
+    /** Reference the invocation goal of the Mojo. */
     private String executeGoal;
 
-    /** Reference the invocation lifecycle of the Mojo */
+    /** Reference the invocation lifecycle of the Mojo. */
     private String executeLifecycle;
 
-    /** Specify the version when the Mojo was deprecated to the API. Similar to Javadoc deprecated. */
+    /**
+     * Specify the version when the Mojo was deprecated to the API. Similar to Javadoc deprecated. This will trigger a
+     * warning when a user tries to configure a parameter marked as deprecated.
+     */
     private String deprecated;
 
-    /** By default, no need to aggregate the Maven project and its child modules */
+    /**
+     * Flags this Mojo to run it in a multi module way, i.e. aggregate the build with the set of projects listed as
+     * modules. By default, no need to aggregate the Maven project and its child modules
+     */
     private boolean aggregator = false;
 
     // ----------------------------------------------------------------------
@@ -94,7 +108,10 @@ public class MojoDescriptor
     /** Specify the required dependencies in a specified scope */
     private String dependencyResolutionRequired = null;
 
-    /** The scope of (transitive) dependencies that should be collected but not resolved. */
+    /**
+     * The scope of (transitive) dependencies that should be collected but not resolved.
+     * @since 3.0-alpha-3
+     */
     private String dependencyCollectionRequired;
 
     /**  By default, the Mojo needs a Maven project to be executed */
@@ -112,13 +129,16 @@ public class MojoDescriptor
     /**  By default, the Mojo is inherited */
     private boolean inheritedByDefault = true;
 
-    /**  By default, the Mojo could not be invoke directly */
+    /**  By default, the Mojo cannot be invoked directly */
     private boolean directInvocationOnly = false;
 
     /**  By default, the Mojo don't need reports to run */
     private boolean requiresReports = false;
 
-    /** By default, mojos are not threadsafe */
+    /**
+     * By default, mojos are not threadsafe
+     * @since 3.0-beta-2
+     */
     private boolean threadSafe = false;
 
     /**
@@ -203,7 +223,7 @@ public class MojoDescriptor
 
         if ( parameters == null )
         {
-            parameters = new LinkedList<Parameter>();
+            parameters = new LinkedList<>();
         }
 
         parameters.add( parameter );
@@ -216,7 +236,7 @@ public class MojoDescriptor
     {
         if ( parameterMap == null )
         {
-            parameterMap = new HashMap<String, Parameter>();
+            parameterMap = new HashMap<>();
 
             if ( parameters != null )
             {
@@ -257,6 +277,9 @@ public class MojoDescriptor
         return dependencyResolutionRequired;
     }
 
+    /**
+     * @since 3.0-alpha-3
+     */
     public void setDependencyCollectionRequired( String requiresDependencyCollection )
     {
         this.dependencyCollectionRequired = requiresDependencyCollection;
@@ -265,9 +288,12 @@ public class MojoDescriptor
     /**
      * Gets the scope of (transitive) dependencies that should be collected. Dependency collection refers to the process
      * of calculating the complete dependency tree in terms of artifact coordinates. In contrast to dependency
-     * resolution, this does not include the download of the files for the dependency artifacts.
+     * resolution, this does not include the download of the files for the dependency artifacts. It is meant for mojos
+     * that only want to analyze the set of transitive dependencies, in particular during early lifecycle phases where
+     * full dependency resolution might fail due to projects which haven't been built yet.
      *
      * @return The scope of (transitive) dependencies that should be collected or {@code null} if none.
+     * @since 3.0-alpha-3
      */
     public String getDependencyCollectionRequired()
     {
@@ -519,12 +545,8 @@ public class MojoDescriptor
                 return false;
             }
 
-            if ( !compareObjects( getGoal(), other.getGoal() ) )
-            {
-                return false;
-            }
+            return compareObjects( getGoal(), other.getGoal() );
 
-            return true;
         }
 
         return false;
@@ -532,7 +554,12 @@ public class MojoDescriptor
 
     private boolean compareObjects( Object first, Object second )
     {
-        if ( ( first == null && second != null ) || ( first != null && second == null ) )
+        if ( first == second )
+        {
+            return true;
+        }
+
+        if ( first == null || second == null )
         {
             return false;
         }
@@ -597,7 +624,7 @@ public class MojoDescriptor
     }
 
     /**
-     * @return <code>true</code> if the Mojo could not be invoke directly, <code>false</code> otherwise.
+     * @return <code>true</code> if the Mojo cannot be invoked directly, <code>false</code> otherwise.
      */
     public boolean isDirectInvocationOnly()
     {
@@ -605,7 +632,7 @@ public class MojoDescriptor
     }
 
     /**
-     * @param directInvocationOnly <code>true</code> if the Mojo could not be invoke directly,
+     * @param directInvocationOnly <code>true</code> if the Mojo cannot be invoked directly,
      * <code>false</code> otherwise.
      */
     public void setDirectInvocationOnly( boolean directInvocationOnly )
@@ -648,6 +675,7 @@ public class MojoDescriptor
 
     /**
      * @return True if the <code>Mojo</code> is thread-safe and can be run safely in parallel
+     * @since 3.0-beta-2
      */
     public boolean isThreadSafe()
     {
@@ -656,6 +684,7 @@ public class MojoDescriptor
 
     /**
      * @param threadSafe indicates that the mojo is thread-safe and can be run safely in parallel
+     * @since 3.0-beta-2
      */
     public void setThreadSafe( boolean threadSafe )
     {
